"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QTextEdit(QAbstractScrollArea):
    """
    https://doc.qt.io/qt-6/qtextedit.html

    **Detailed Description**

    **Introduction and Concepts**

    QTextEdit is an advanced WYSIWYG viewer/editor supporting rich text
    formatting using HTML-style tags, or Markdown format. It is optimized to
    handle large documents and to respond quickly to user input.

    QTextEdit works on paragraphs and characters. A paragraph is a formatted
    string which is word-wrapped to fit into the width of the widget. By default
    when reading plain text, one newline signifies a paragraph. A document
    consists of zero or more paragraphs. The words in the paragraph are aligned
    in accordance with the paragraph's alignment. Paragraphs are separated by
    hard line breaks. Each character within a paragraph has its own attributes,
    for example, font and color.

    QTextEdit can display images, lists and tables. If the text is too large to
    view within the text edit's viewport, scroll bars will appear. The text edit
    can load both plain text and rich text files. Rich text can be described
    using a subset of HTML 4 markup; refer to the **Supported HTML Subset**
    page for more information.

    If you just need to display a small piece of rich text use **QLabel** .

    The rich text support in Qt is designed to provide a fast, portable and
    efficient way to add reasonable online help facilities to applications, and
    to provide a basis for rich text editors. If you find the HTML support
    insufficient for your needs you may consider the use of Qt WebKit, which
    provides a full-featured web browser widget.

    The shape of the mouse cursor on a QTextEdit is **Qt::IBeamCursor**  by
    default. It can be changed through the **viewport** ()'s cursor property.

    **Using QTextEdit as a Display Widget**

    QTextEdit can display a large HTML subset, including tables and images.

    The text can be set or replaced using **setHtml** () which deletes any
    existing text and replaces it with the text passed in the **setHtml** ()
    call. If you call **setHtml** () with legacy HTML, and then call **toHtml**
    (), the text that is returned may have different markup, but will render the
    same. The entire text can be deleted with **clear** ().

    Text can also be set or replaced using **setMarkdown** (), and the same
    caveats apply: if you then call **toMarkdown** (), the text that is returned
    may be different, but the meaning is preserved as much as possible. Markdown
    with some embedded HTML can be parsed, with the same limitations that
    **setHtml** () has; but **toMarkdown** () only writes "pure" Markdown,
    without any embedded HTML.

    Text itself can be inserted using the **QTextCursor**  class or using the
    convenience functions **insertHtml** (), **insertPlainText** (), **append**
    () or **paste** (). **QTextCursor**  is also able to insert complex objects
    like tables or lists into the document, and it deals with creating
    selections and applying changes to selected text.

    By default the text edit wraps words at whitespace to fit within the text
    edit widget. The **setLineWrapMode** () function is used to specify the kind
    of line wrap you want, or **NoWrap**  if you don't want any wrapping. Call
    **setLineWrapMode** () to set a fixed pixel width **FixedPixelWidth** , or
    character column (e.g. 80 column) **FixedColumnWidth**  with the pixels or
    columns specified with **setLineWrapColumnOrWidth** (). If you use word wrap
    to the widget's width **WidgetWidth** , you can specify whether to break on
    whitespace or anywhere with **setWordWrapMode** ().

    The **find** () function can be used to find and select a given string
    within the text.

    If you want to limit the total number of paragraphs in a QTextEdit, as for
    example it is often useful in a log viewer, then you can use
    **QTextDocument** 's maximumBlockCount property for that.

    **Read-only Key Bindings**

    When QTextEdit is used read-only the key bindings are limited to navigation,
    and text may only be selected with the mouse:

    KeypressesAction
    UpMoves one line up.
    DownMoves one line down.
    LeftMoves one character to the left.
    RightMoves one character to the
    right.
    PageUpMoves one (viewport) page up.
    PageDownMoves one (viewport)
    page down.
    HomeMoves to the beginning of the text.
    EndMoves to the end
    of the text.
    Alt+WheelScrolls the page horizontally (the Wheel is the
    mouse wheel).
    Ctrl+WheelZooms the text.
    Ctrl+ASelects all text.

    The text edit may be able to provide some meta-information. For example, the
    **documentTitle** () function will return the text from within HTML
    `<title>` tags.

    **Note:** Zooming into HTML documents only works if the font-size is not set
    to a fixed size.

    **Using QTextEdit as an Editor**

    All the information about using QTextEdit as a display widget also applies
    here.

    The current char format's attributes are set with **setFontItalic** (),
    **setFontWeight** (), **setFontUnderline** (), **setFontFamily** (),
    **setFontPointSize** (), **setTextColor** () and **setCurrentFont** (). The
    current paragraph's alignment is set with **setAlignment** ().

    Selection of text is handled by the **QTextCursor**  class, which provides
    functionality for creating selections, retrieving the text contents or
    deleting selections. You can retrieve the object that corresponds with the
    user-visible cursor using the **textCursor** () method. If you want to set a
    selection in QTextEdit just create one on a **QTextCursor**  object and then
    make that cursor the visible cursor using **setTextCursor** (). The
    selection can be copied to the clipboard with **copy** (), or cut to the
    clipboard with **cut** (). The entire text can be selected using
    **selectAll** ().

    When the cursor is moved and the underlying formatting attributes change,
    the **currentCharFormatChanged** () signal is emitted to reflect the new
    attributes at the new cursor position.

    The **textChanged** () signal is emitted whenever the text changes (as a
    result of **setText** () or through the editor itself).

    QTextEdit holds a **QTextDocument**  object which can be retrieved using the
    **document** () method. You can also set your own document object using
    **setDocument** ().

    **QTextDocument**  provides an **isModified** () function which will return
    true if the text has been modified since it was either loaded or since the
    last call to setModified with false as argument. In addition it provides
    methods for undo and redo.

    **Drag and Drop**

    QTextEdit also supports custom drag and drop behavior. By default, QTextEdit
    will insert plain text, HTML and rich text when the user drops data of these
    MIME types onto a document. Reimplement **canInsertFromMimeData** () and
    **insertFromMimeData** () to add support for additional MIME types.

    For example, to allow the user to drag and drop an image onto a QTextEdit,
    you could the implement these functions in the following way:

    bool TextEdit::canInsertFromMimeData( const **QMimeData**  *source ) const
    {
            if (source->hasImage())
                return true;
            else
    return **QTextEdit** ::canInsertFromMimeData(source);
        }

    We add support for image MIME types by returning true. For all other MIME
    types, we use the default implementation.

    void TextEdit::insertFromMimeData( const **QMimeData**  *source )
        {
    if (source->hasImage())
            {
                **QImage**  image =
    qvariant_cast<**QImage** >(source->imageData());
                **QTextCursor**
    cursor = this->textCursor();
                **QTextDocument**  *document =
    this->document();
                document->addResource(**QTextDocument**
    ::ImageResource, **QUrl** ("image"), image);
    cursor.insertImage("image");
            }
        }

    We unpack the image from the **QVariant**  held by the MIME source and
    insert it into the document as a resource.

    **Editing Key Bindings**

    The list of key bindings which are implemented for editing:

    KeypressesAction
    BackspaceDeletes the character to the left of the cursor.
    DeleteDeletes the character to the right of the cursor.
    Ctrl+CCopy the
    selected text to the clipboard.
    Ctrl+InsertCopy the selected text to the
    clipboard.
    Ctrl+KDeletes to the end of the line.
    Ctrl+VPastes the
    clipboard text into text edit.
    Shift+InsertPastes the clipboard text into
    text edit.
    Ctrl+XDeletes the selected text and copies it to the clipboard.
    Shift+DeleteDeletes the selected text and copies it to the clipboard.
    Ctrl+ZUndoes the last operation.
    Ctrl+YRedoes the last operation.
    LeftMoves the cursor one character to the left.
    Ctrl+LeftMoves the cursor
    one word to the left.
    RightMoves the cursor one character to the right.
    Ctrl+RightMoves the cursor one word to the right.
    UpMoves the cursor one
    line up.
    DownMoves the cursor one line down.
    PageUpMoves the cursor one
    page up.
    PageDownMoves the cursor one page down.
    HomeMoves the cursor to
    the beginning of the line.
    Ctrl+HomeMoves the cursor to the beginning of
    the text.
    EndMoves the cursor to the end of the line.
    Ctrl+EndMoves the
    cursor to the end of the text.
    Alt+WheelScrolls the page horizontally (the
    Wheel is the mouse wheel).

    To select (mark) text hold down the Shift key whilst pressing one of the
    movement keystrokes, for example, **Shift+Right** will select the character
    to the right, and **Shift+Ctrl+Right** will select the word to the right,
    etc.

    **See also** **QTextDocument** , **QTextCursor** , **Qt Widgets -
    Application Example** , **Syntax Highlighter Example** , and **Rich Text
    Processing** .
    """

    class AutoFormattingFlag(enum.Flag):
        AutoNone: QTextEdit = ...
        AutoBulletList: QTextEdit = ...
        AutoAll: QTextEdit = ...

    class LineWrapMode(enum.Enum):
        NoWrap: QTextEdit = ...
        WidgetWidth: QTextEdit = ...
        FixedPixelWidth: QTextEdit = ...
        FixedColumnWidth: QTextEdit = ...

    class ExtraSelection(PyQt6.sip.simplewrapper):
        cursor: QtGui = ...
        format: QtGui = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QTextEdit.ExtraSelection") -> None:
            ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#QTextEdit

        **QTextEdit::QTextEdit(QWidget * parent = nullptr)**

        Constructs an empty QTextEdit with parent **parent**.
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#QTextEdit-1

        **QTextEdit::QTextEdit(const QString & text , QWidget * parent =
        nullptr)**

        Constructs a QTextEdit with parent **parent**. The text edit will
        display the text **text**. The text is interpreted as html.
        """
        ...

    def setMarkdown(self, markdown: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#markdown-prop

        **[since 5.14] markdown : QString**

        This property provides a Markdown interface to the text of the text
        edit.

        `toMarkdown()` returns the text of the text edit as "pure" Markdown,
        without any embedded HTML formatting. Some features that
        **QTextDocument**  supports (such as the use of specific colors and
        named fonts) cannot be expressed in "pure" Markdown, and they will be
        omitted.

        `setMarkdown()` changes the text of the text edit. Any previous text is
        removed and the undo/redo history is cleared. The input text is
        interpreted as rich text in Markdown format.

        Parsing of HTML included in the **markdown** string is handled in the
        same way as in **setHtml** ; however, Markdown formatting inside HTML
        blocks is not supported.

        Some features of the parser can be enabled or disabled via the
        **features** argument:

        ConstantDescription
        `MarkdownNoHTML`Any HTML tags in the Markdown text
        will be discarded
        `MarkdownDialectCommonMark`The parser supports only
        the features standardized by CommonMark
        `MarkdownDialectGitHub`The
        parser supports the GitHub dialect

        The default is `MarkdownDialectGitHub`.

        This property was introduced in Qt 5.14.

        **Access functions:**

        QString **toMarkdown** (QTextDocument::MarkdownFeatures **features** =
        QTextDocument::MarkdownDialectGitHub) const
        void **setMarkdown**
        (const QString & **markdown** )

        **Notifier signal:**

        void ****textChanged** ** ()

        **See also** **plainText** , **html** , **QTextDocument::toMarkdown**
        (), and **QTextDocument::setMarkdown** ().
        """
        ...

    def toMarkdown(self, features: QtGui.QTextDocument.MarkdownFeature = ...) -> str:
        ...

    def setTabStopDistance(self, distance: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#tabStopDistance-prop

        **[since 5.10] tabStopDistance : qreal**

        This property holds the tab stop distance in pixels

        By default, this property contains a value of 80 pixels.

        Do not set a value less than the **horizontalAdvance** () of the
        **QChar::VisualTabCharacter**  character, otherwise the tab-character
        will be drawn incompletely.

        This property was introduced in Qt 5.10.

        **Access functions:**

        qreal **tabStopDistance** () const
        void **setTabStopDistance** (qreal
        **distance** )

        **See also** **QTextOption::ShowTabsAndSpaces**  and
        **QTextDocument::defaultTextOption** .
        """
        ...

    def tabStopDistance(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextedit.html#tabStopDistance-prop

        **[since 5.10] tabStopDistance : qreal**

        This property holds the tab stop distance in pixels

        By default, this property contains a value of 80 pixels.

        Do not set a value less than the **horizontalAdvance** () of the
        **QChar::VisualTabCharacter**  character, otherwise the tab-character
        will be drawn incompletely.

        This property was introduced in Qt 5.10.

        **Access functions:**

        qreal **tabStopDistance** () const
        void **setTabStopDistance** (qreal
        **distance** )

        **See also** **QTextOption::ShowTabsAndSpaces**  and
        **QTextDocument::defaultTextOption** .
        """
        ...

    def placeholderText(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextedit.html#placeholderText-prop

        **[since 5.2] placeholderText : QString**

        This property holds the editor placeholder text

        Setting this property makes the editor display a grayed-out placeholder
        text as long as the **document** () is empty.

        By default, this property contains an empty string.

        This property was introduced in Qt 5.2.

        **Access functions:**

        QString **placeholderText** () const
        void **setPlaceholderText**
        (const QString & **placeholderText** )

        **See also** **document** ().
        """
        ...

    def setPlaceholderText(self, placeholderText: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#placeholderText-prop

        **[since 5.2] placeholderText : QString**

        This property holds the editor placeholder text

        Setting this property makes the editor display a grayed-out placeholder
        text as long as the **document** () is empty.

        By default, this property contains an empty string.

        This property was introduced in Qt 5.2.

        **Access functions:**

        QString **placeholderText** () const
        void **setPlaceholderText**
        (const QString & **placeholderText** )

        **See also** **document** ().
        """
        ...

    def setTextBackgroundColor(
        self, c: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setTextBackgroundColor

        **[slot] void QTextEdit::setTextBackgroundColor(const QColor & c )**

        Sets the text background color of the current format to **c**.

        **See also** **textBackgroundColor** ().
        """
        ...

    def textBackgroundColor(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qtextedit.html#textBackgroundColor

        **QColor QTextEdit::textBackgroundColor() const**

        Returns the text background color of the current format.

        **See also** **setTextBackgroundColor** ().
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#scrollContentsBy

        **[override virtual protected] void QTextEdit::scrollContentsBy(int dx ,
        int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).
        """
        ...

    @typing.overload
    def inputMethodQuery(self, property: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextedit.html#inputMethodQuery

        **[override virtual] QVariant
        QTextEdit::inputMethodQuery(Qt::InputMethodQuery property ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    @typing.overload
    def inputMethodQuery(
        self, query: QtCore.Qt.InputMethodQuery, argument: typing.Any
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextedit.html#inputMethodQuery

        **[override virtual] QVariant
        QTextEdit::inputMethodQuery(Qt::InputMethodQuery property ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    def inputMethodEvent(self, a0: QtGui.QInputMethodEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#inputMethodEvent

        **[override virtual protected] void
        QTextEdit::inputMethodEvent(QInputMethodEvent * e )**

        Reimplements: **QWidget::inputMethodEvent** (QInputMethodEvent *event).
        """
        ...

    def insertFromMimeData(self, source: QtCore.QMimeData) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#insertFromMimeData

        **[virtual protected] void QTextEdit::insertFromMimeData(const QMimeData
        * source )**

        This function inserts the contents of the MIME data object, specified by
        **source** , into the text edit at the current cursor position. It is
        called whenever text is inserted as the result of a clipboard paste
        operation, or when the text edit accepts data from a drag and drop
        operation.

        Reimplement this function to enable drag and drop support for additional
        MIME types.
        """
        ...

    def canInsertFromMimeData(self, source: QtCore.QMimeData) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#canInsertFromMimeData

        **[virtual protected] bool QTextEdit::canInsertFromMimeData(const
        QMimeData * source ) const**

        This function returns `true` if the contents of the MIME data object,
        specified by **source** , can be decoded and inserted into the document.
        It is called for example when during a drag operation the mouse enters
        this widget and it is necessary to determine whether it is possible to
        accept the drag and drop operation.

        Reimplement this function to enable drag and drop support for additional
        MIME types.
        """
        ...

    def createMimeDataFromSelection(self) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qtextedit.html#createMimeDataFromSelection

        **[virtual protected] QMimeData
        *QTextEdit::createMimeDataFromSelection() const**

        This function returns a new MIME data object to represent the contents
        of the text edit's current selection. It is called when the selection
        needs to be encapsulated into a new **QMimeData**  object; for example,
        when a drag and drop operation is started, or when data is copied to the
        clipboard.

        If you reimplement this function, note that the ownership of the
        returned **QMimeData**  object is passed to the caller. The selection
        can be retrieved by using the **textCursor** () function.
        """
        ...

    def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#wheelEvent

        **[override virtual protected] void QTextEdit::wheelEvent(QWheelEvent *
        e )**

        Reimplements: **QAbstractScrollArea::wheelEvent** (QWheelEvent *e).
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#changeEvent

        **[override virtual protected] void QTextEdit::changeEvent(QEvent * e
        )**

        Reimplements: **QFrame::changeEvent** (QEvent *ev).
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#showEvent

        **[override virtual protected] void QTextEdit::showEvent(QShowEvent *)**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def focusOutEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#focusOutEvent

        **[override virtual protected] void QTextEdit::focusOutEvent(QFocusEvent
        * e )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#focusInEvent

        **[override virtual protected] void QTextEdit::focusInEvent(QFocusEvent
        * e )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def dropEvent(self, e: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#dropEvent

        **[override virtual protected] void QTextEdit::dropEvent(QDropEvent * e
        )**

        Reimplements: **QAbstractScrollArea::dropEvent** (QDropEvent *event).
        """
        ...

    def dragMoveEvent(self, e: QtGui.QDragMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#dragMoveEvent

        **[override virtual protected] void
        QTextEdit::dragMoveEvent(QDragMoveEvent * e )**

        Reimplements: **QAbstractScrollArea::dragMoveEvent** (QDragMoveEvent
        *event).
        """
        ...

    def dragLeaveEvent(self, e: QtGui.QDragLeaveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#dragLeaveEvent

        **[override virtual protected] void
        QTextEdit::dragLeaveEvent(QDragLeaveEvent * e )**

        Reimplements: **QAbstractScrollArea::dragLeaveEvent** (QDragLeaveEvent
        *event).
        """
        ...

    def dragEnterEvent(self, e: QtGui.QDragEnterEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#dragEnterEvent

        **[override virtual protected] void
        QTextEdit::dragEnterEvent(QDragEnterEvent * e )**

        Reimplements: **QAbstractScrollArea::dragEnterEvent** (QDragEnterEvent
        *event).
        """
        ...

    def contextMenuEvent(self, e: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#contextMenuEvent

        **[override virtual protected] void
        QTextEdit::contextMenuEvent(QContextMenuEvent * event )**

        Reimplements: **QAbstractScrollArea::contextMenuEvent**
        (QContextMenuEvent *e).

        Shows the standard context menu created with
        **createStandardContextMenu** ().

        If you do not want the text edit to have a context menu, you can set its
        **contextMenuPolicy**  to **Qt::NoContextMenu** . If you want to
        customize the context menu, reimplement this function. If you want to
        extend the standard context menu, reimplement this function, call
        **createStandardContextMenu** () and extend the menu returned.

        Information about the event is passed in the **event** object.

        void MyTextEdit::contextMenuEvent(**QContextMenuEvent**  *event)
            {
        **QMenu**  *menu = createStandardContextMenu();
        menu->addAction(tr("My Menu Item"));
                //...
        menu->exec(event->globalPos());
                delete menu;
            }
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#focusNextPrevChild

        **[override virtual protected] bool QTextEdit::focusNextPrevChild(bool
        next )**

        Reimplements: **QWidget::focusNextPrevChild** (bool next).
        """
        ...

    def mouseDoubleClickEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QTextEdit::mouseDoubleClickEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mouseDoubleClickEvent**
        (QMouseEvent *e).
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#mouseReleaseEvent

        **[override virtual protected] void
        QTextEdit::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mouseReleaseEvent** (QMouseEvent
        *e).
        """
        ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#mouseMoveEvent

        **[override virtual protected] void
        QTextEdit::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mouseMoveEvent** (QMouseEvent *e).
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#mousePressEvent

        **[override virtual protected] void
        QTextEdit::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QAbstractScrollArea::mousePressEvent** (QMouseEvent *e).
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#paintEvent

        **[override virtual protected] void QTextEdit::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QAbstractScrollArea::paintEvent** (QPaintEvent *event).

        This event handler can be reimplemented in a subclass to receive paint
        events passed in **event**. It is usually unnecessary to reimplement
        this function in a subclass of **QTextEdit** .

        **Warning:** The underlying text document must not be modified from
        within a reimplementation of this function.
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#resizeEvent

        **[override virtual protected] void QTextEdit::resizeEvent(QResizeEvent
        * e )**

        Reimplements: **QAbstractScrollArea::resizeEvent** (QResizeEvent
        *event).
        """
        ...

    def keyReleaseEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#keyReleaseEvent

        **[override virtual protected] void QTextEdit::keyReleaseEvent(QKeyEvent
        * e )**

        Reimplements: **QWidget::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#keyPressEvent

        **[override virtual protected] void QTextEdit::keyPressEvent(QKeyEvent *
        e )**

        Reimplements: **QAbstractScrollArea::keyPressEvent** (QKeyEvent *e).
        """
        ...

    def timerEvent(self, e: QtCore.QTimerEvent) -> None:
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        ...

    def zoomOut(self, range: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#zoomOut

        **[slot] void QTextEdit::zoomOut(int range = 1)**

        Zooms out on the text by making the base font size **range** points
        smaller and recalculating all font sizes to be the new size. This does
        not change the size of any images.

        **See also** **zoomIn** ().
        """
        ...

    def zoomIn(self, range: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#zoomIn

        **[slot] void QTextEdit::zoomIn(int range = 1)**

        Zooms in on the text by making the base font size **range** points
        larger and recalculating all font sizes to be the new size. This does
        not change the size of any images.

        **See also** **zoomOut** ().
        """
        ...

    def undo(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#undo

        **[slot] void QTextEdit::undo()**

        Undoes the last operation.

        If there is no operation to undo, i.e. there is no undo step in the
        undo/redo history, nothing happens.

        **See also** **redo** ().
        """
        ...

    def redo(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#redo

        **[slot] void QTextEdit::redo()**

        Redoes the last operation.

        If there is no operation to redo, i.e. there is no redo step in the
        undo/redo history, nothing happens.

        **See also** **undo** ().
        """
        ...

    def scrollToAnchor(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#scrollToAnchor

        **[slot] void QTextEdit::scrollToAnchor(const QString & name )**

        Scrolls the text edit so that the anchor with the given **name** is
        visible; does nothing if the **name** is empty, or is already visible,
        or isn't found.
        """
        ...

    def insertHtml(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#insertHtml

        **[slot] void QTextEdit::insertHtml(const QString & text )**

        Convenience slot that inserts **text** which is assumed to be of html
        formatting at the current cursor position.

        It is equivalent to:

        edit->textCursor().insertHtml(fragment);

        **Note:** When using this function with a style sheet, the style sheet
        will only apply to the current block in the document. In order to apply
        a style sheet throughout a document, use
        **QTextDocument::setDefaultStyleSheet** () instead.
        """
        ...

    def insertPlainText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#insertPlainText

        **[slot] void QTextEdit::insertPlainText(const QString & text )**

        Convenience slot that inserts **text** at the current cursor position.

        It is equivalent to

        edit->textCursor().insertText(text);
        """
        ...

    def selectAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#selectAll

        **[slot] void QTextEdit::selectAll()**

        Selects all text.

        **See also** **copy** (), **cut** (), and **textCursor** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#clear

        **[slot] void QTextEdit::clear()**

        Deletes all the text in the text edit.

        Notes:

        * The undo/redo history is also cleared.
          * **currentCharFormat** () is
        reset, unless **textCursor** () is already at the beginning of the
        document.

        **See also** **cut** (), **setPlainText** (), and **setHtml** ().
        """
        ...

    def paste(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#paste

        **[slot] void QTextEdit::paste()**

        Pastes the text from the clipboard into the text edit at the current
        cursor position.

        If there is no text in the clipboard nothing happens.

        To change the behavior of this function, i.e. to modify what
        **QTextEdit**  can paste and how it is being pasted, reimplement the
        virtual **canInsertFromMimeData** () and **insertFromMimeData** ()
        functions.

        **See also** **cut** () and **copy** ().
        """
        ...

    def copy(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#copy

        **[slot] void QTextEdit::copy()**

        Copies any selected text to the clipboard.

        **See also** **copyAvailable** ().
        """
        ...

    def cut(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#cut

        **[slot] void QTextEdit::cut()**

        Copies the selected text to the clipboard and deletes it from the text
        edit.

        If there is no selected text nothing happens.

        **See also** **copy** () and **paste** ().
        """
        ...

    def setHtml(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#html-prop

        **html : QString**

        This property provides an HTML interface to the text of the text edit.

        toHtml() returns the text of the text edit as html.

        setHtml() changes the text of the text edit. Any previous text is
        removed and the undo/redo history is cleared. The input text is
        interpreted as rich text in html format. **currentCharFormat** () is
        also reset, unless **textCursor** () is already at the beginning of the
        document.

        **Note:** It is the responsibility of the caller to make sure that the
        text is correctly decoded when a **QString**  containing HTML is created
        and passed to setHtml().

        By default, for a newly-created, empty document, this property contains
        text to describe an HTML 4.0 document with no body text.

        **Access functions:**

        QString **toHtml** () const
        void **setHtml** (const QString & **text**
        )

        **Notifier signal:**

        void ****textChanged** ** ()

        **See also** **Supported HTML Subset**  and **plainText** .
        """
        ...

    def setPlainText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setPlainText

        **[slot] void QTextEdit::setPlainText(const QString & text )**

        Changes the text of the text edit to the string **text**. Any previous
        text is removed.

        Notes:

        * **text** is interpreted as plain text.
          * The undo/redo history is
        also cleared.
          * **currentCharFormat** () is reset, unless
        **textCursor** () is already at the beginning of the document.

        **Note:** Setter function for property **plainText** .

        **See also** **toPlainText** ().
        """
        ...

    def setAlignment(self, a: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setAlignment

        **[slot] void QTextEdit::setAlignment(Qt::Alignment a )**

        Sets the alignment of the current paragraph to **a**. Valid alignments
        are **Qt::AlignLeft** , **Qt::AlignRight** , **Qt::AlignJustify**  and
        **Qt::AlignCenter**  (which centers horizontally).

        **See also** **alignment** ().
        """
        ...

    def setCurrentFont(self, f: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setCurrentFont

        **[slot] void QTextEdit::setCurrentFont(const QFont & f )**

        Sets the font of the current format to **f**.

        **See also** **currentFont** (), **setFontPointSize** (), and
        **setFontFamily** ().
        """
        ...

    def setTextColor(
        self, c: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setTextColor

        **[slot] void QTextEdit::setTextColor(const QColor & c )**

        Sets the text color of the current format to **c**.

        **See also** **textColor** ().
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setText

        **[slot] void QTextEdit::setText(const QString & text )**

        Sets the text edit's **text**. The text can be plain text or HTML and
        the text edit will try to guess the right format.

        Use **setHtml** () or **setPlainText** () directly to avoid text edit's
        guessing.

        **See also** **toPlainText** () and **toHtml** ().
        """
        ...

    def setFontItalic(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setFontItalic

        **[slot] void QTextEdit::setFontItalic(bool italic )**

        If **italic** is true, sets the current format to italic; otherwise sets
        the current format to non-italic.

        **See also** **fontItalic** ().
        """
        ...

    def setFontUnderline(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setFontUnderline

        **[slot] void QTextEdit::setFontUnderline(bool underline )**

        If **underline** is true, sets the current format to underline;
        otherwise sets the current format to non-underline.

        **See also** **fontUnderline** ().
        """
        ...

    def setFontWeight(self, w: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setFontWeight

        **[slot] void QTextEdit::setFontWeight(int weight )**

        Sets the font weight of the current format to the given **weight** ,
        where the value used is in the range defined by the **QFont::Weight**
        enum.

        **See also** **fontWeight** (), **setCurrentFont** (), and
        **setFontFamily** ().
        """
        ...

    def setFontFamily(self, fontFamily: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setFontFamily

        **[slot] void QTextEdit::setFontFamily(const QString & fontFamily )**

        Sets the font family of the current format to **fontFamily**.

        **See also** **fontFamily** () and **setCurrentFont** ().
        """
        ...

    def setFontPointSize(self, s: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setFontPointSize

        **[slot] void QTextEdit::setFontPointSize(qreal s )**

        Sets the point size of the current format to **s**.

        Note that if **s** is zero or negative, the behavior of this function is
        not defined.

        **See also** **fontPointSize** (), **setCurrentFont** (), and
        **setFontFamily** ().
        """
        ...

    def print(self, printer: QtGui.QPagedPaintDevice) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#print

        **void QTextEdit::print(QPagedPaintDevice * printer ) const**

        Convenience function to print the text edit's document to the given
        **printer**. This is equivalent to calling the print method on the
        document directly except that this function also supports
        QPrinter::Selection as print range.

        **See also** **QTextDocument::print** ().
        """
        ...

    def moveCursor(
        self,
        operation: QtGui.QTextCursor.MoveOperation,
        mode: QtGui.QTextCursor.MoveMode = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#moveCursor

        **void QTextEdit::moveCursor(QTextCursor::MoveOperation operation ,
        QTextCursor::MoveMode mode = QTextCursor::MoveAnchor)**

        Moves the cursor by performing the given **operation**.

        If **mode** is **QTextCursor::KeepAnchor** , the cursor selects the text
        it moves over. This is the same effect that the user achieves when they
        hold down the Shift key and move the cursor with the cursor keys.

        **See also** **QTextCursor::movePosition** ().
        """
        ...

    def canPaste(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#canPaste

        **bool QTextEdit::canPaste() const**

        Returns whether text can be pasted from the clipboard into the textedit.
        """
        ...

    def extraSelections(self) -> typing.List["QTextEdit.ExtraSelection"]:
        """
        https://doc.qt.io/qt-6/qtextedit.html#extraSelections

        **QList<QTextEdit::ExtraSelection> QTextEdit::extraSelections() const**

        Returns previously set extra selections.

        **See also** **setExtraSelections** ().
        """
        ...

    def setExtraSelections(
        self, selections: typing.Iterable["QTextEdit.ExtraSelection"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setExtraSelections

        **void QTextEdit::setExtraSelections(const
        QList<QTextEdit::ExtraSelection> & selections )**

        This function allows temporarily marking certain regions in the document
        with a given color, specified as **selections**. This can be useful for
        example in a programming editor to mark a whole line of text with a
        given background color to indicate the existence of a breakpoint.

        **See also** **QTextEdit::ExtraSelection**  and **extraSelections** ().
        """
        ...

    def cursorWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextedit.html#cursorWidth-prop

        **cursorWidth : int**

        This property specifies the width of the cursor in pixels. The default
        value is 1.

        **Access functions:**

        int **cursorWidth** () const
        void **setCursorWidth** (int **width** )
        """
        ...

    def setCursorWidth(self, width: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#cursorWidth-prop

        **cursorWidth : int**

        This property specifies the width of the cursor in pixels. The default
        value is 1.

        **Access functions:**

        int **cursorWidth** () const
        void **setCursorWidth** (int **width** )
        """
        ...

    def textInteractionFlags(self) -> QtCore.Qt.TextInteractionFlag:
        """
        https://doc.qt.io/qt-6/qtextedit.html#textInteractionFlags-prop

        **textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the widget should interact with user input.

        The default value depends on whether the **QTextEdit**  is read-only or
        editable, and whether it is a **QTextBrowser**  or not.

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )
        """
        ...

    def setTextInteractionFlags(self, flags: QtCore.Qt.TextInteractionFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#textInteractionFlags-prop

        **textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the widget should interact with user input.

        The default value depends on whether the **QTextEdit**  is read-only or
        editable, and whether it is a **QTextBrowser**  or not.

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )
        """
        ...

    def setAcceptRichText(self, accept: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#acceptRichText-prop

        **acceptRichText : bool**

        This property holds whether the text edit accepts rich text insertions
        by the user

        When this propery is set to false text edit will accept only plain text
        input from the user. For example through clipboard or drag and drop.

        This property's default is true.

        **Access functions:**

        bool **acceptRichText** () const
        void **setAcceptRichText** (bool
        **accept** )
        """
        ...

    def acceptRichText(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#acceptRichText-prop

        **acceptRichText : bool**

        This property holds whether the text edit accepts rich text insertions
        by the user

        When this propery is set to false text edit will accept only plain text
        input from the user. For example through clipboard or drag and drop.

        This property's default is true.

        **Access functions:**

        bool **acceptRichText** () const
        void **setAcceptRichText** (bool
        **accept** )
        """
        ...

    def setOverwriteMode(self, overwrite: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#overwriteMode-prop

        **overwriteMode : bool**

        This property holds whether text entered by the user will overwrite
        existing text

        As with many text editors, the text editor widget can be configured to
        insert or overwrite existing text with new text entered by the user.

        If this property is `true`, existing text is overwritten, character-for-
        character by new text; otherwise, text is inserted at the cursor
        position, displacing existing text.

        By default, this property is `false` (new text does not overwrite
        existing text).

        **Access functions:**

        bool **overwriteMode** () const
        void **setOverwriteMode** (bool
        **overwrite** )
        """
        ...

    def overwriteMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#overwriteMode-prop

        **overwriteMode : bool**

        This property holds whether text entered by the user will overwrite
        existing text

        As with many text editors, the text editor widget can be configured to
        insert or overwrite existing text with new text entered by the user.

        If this property is `true`, existing text is overwritten, character-for-
        character by new text; otherwise, text is inserted at the cursor
        position, displacing existing text.

        By default, this property is `false` (new text does not overwrite
        existing text).

        **Access functions:**

        bool **overwriteMode** () const
        void **setOverwriteMode** (bool
        **overwrite** )
        """
        ...

    def anchorAt(self, pos: QtCore.QPoint) -> str:
        """
        https://doc.qt.io/qt-6/qtextedit.html#anchorAt

        **QString QTextEdit::anchorAt(const QPoint & pos ) const**

        Returns the reference of the anchor at position **pos** , or an empty
        string if no anchor exists at that point.
        """
        ...

    @typing.overload
    def cursorRect(self, cursor: QtGui.QTextCursor) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtextedit.html#cursorRect

        **QRect QTextEdit::cursorRect(const QTextCursor & cursor ) const**

        returns a rectangle (in viewport coordinates) that includes the
        **cursor**.
        """
        ...

    @typing.overload
    def cursorRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtextedit.html#cursorRect-1

        **QRect QTextEdit::cursorRect() const**

        returns a rectangle (in viewport coordinates) that includes the cursor
        of the text edit.
        """
        ...

    def cursorForPosition(self, pos: QtCore.QPoint) -> QtGui.QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextedit.html#cursorForPosition

        **QTextCursor QTextEdit::cursorForPosition(const QPoint & pos ) const**

        returns a **QTextCursor**  at position **pos** (in viewport
        coordinates).
        """
        ...

    @typing.overload
    def createStandardContextMenu(self) -> QMenu:
        """
        https://doc.qt.io/qt-6/qtextedit.html#createStandardContextMenu

        **QMenu *QTextEdit::createStandardContextMenu()**

        This function creates the standard context menu which is shown when the
        user clicks on the text edit with the right mouse button. It is called
        from the default **contextMenuEvent** () handler. The popup menu's
        ownership is transferred to the caller.

        We recommend that you use the createStandardContextMenu(**QPoint** )
        version instead which will enable the actions that are sensitive to
        where the user clicked.
        """
        ...

    @typing.overload
    def createStandardContextMenu(self, position: QtCore.QPoint) -> QMenu:
        """
        https://doc.qt.io/qt-6/qtextedit.html#createStandardContextMenu-1

        **QMenu *QTextEdit::createStandardContextMenu(const QPoint & position
        )**

        This function creates the standard context menu which is shown when the
        user clicks on the text edit with the right mouse button. It is called
        from the default **contextMenuEvent** () handler and it takes the
        **position** in document coordinates where the mouse click was. This can
        enable actions that are sensitive to the position where the user
        clicked. The popup menu's ownership is transferred to the caller.
        """
        ...

    def loadResource(self, type: int, name: QtCore.QUrl) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextedit.html#loadResource

        **[virtual invokable] QVariant QTextEdit::loadResource(int type , const
        QUrl & name )**

        Loads the resource specified by the given **type** and **name**.

        This function is an extension of **QTextDocument::loadResource** ().

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QTextDocument::loadResource** ().
        """
        ...

    def ensureCursorVisible(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#ensureCursorVisible

        **void QTextEdit::ensureCursorVisible()**

        Ensures that the cursor is visible by scrolling the text edit if
        necessary.
        """
        ...

    def append(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#append

        **[slot] void QTextEdit::append(const QString & text )**

        Appends a new paragraph with **text** to the end of the text edit.

        **Note:** The new paragraph appended will have the same character format
        and block format as the current paragraph, determined by the position of
        the cursor.

        **See also** **currentCharFormat** () and **QTextCursor::blockFormat**
        ().
        """
        ...

    def toHtml(self) -> str:
        ...

    def toPlainText(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextedit.html#toPlainText

        **QString QTextEdit::toPlainText() const**

        **QString**  QTextEdit::toPlainText() const

        Returns the text of the text edit as plain text.

        **Note:** Getter function for property **plainText** .

        **See also** **QTextEdit::setPlainText** ().
        """
        ...

    @typing.overload
    def find(self, exp: str, options: QtGui.QTextDocument.FindFlag = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#find

        **bool QTextEdit::find(const QString & exp , QTextDocument::FindFlags
        options = QTextDocument::FindFlags())**

        Finds the next occurrence of the string, **exp** , using the given
        **options**. Returns `true` if **exp** was found and changes the cursor
        to select the match; otherwise returns `false`.
        """
        ...

    @typing.overload
    def find(
        self,
        exp: QtCore.QRegularExpression,
        options: QtGui.QTextDocument.FindFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#find-1

        **[since 5.13] bool QTextEdit::find(const QRegularExpression & exp ,
        QTextDocument::FindFlags options = QTextDocument::FindFlags())**

        This is an overloaded function.

        Finds the next occurrence, matching the regular expression, **exp** ,
        using the given **options**. The **QTextDocument::FindCaseSensitively**
        option is ignored for this overload, use
        **QRegularExpression::CaseInsensitiveOption**  instead.

        Returns `true` if a match was found and changes the cursor to select the
        match; otherwise returns `false`.

        This function was introduced in Qt 5.13.
        """
        ...

    def setWordWrapMode(self, policy: QtGui.QTextOption.WrapMode) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#wordWrapMode-prop

        **wordWrapMode : QTextOption::WrapMode**

        This property holds the mode **QTextEdit**  will use when wrapping text
        by words

        By default, this property is set to
        **QTextOption::WrapAtWordBoundaryOrAnywhere** .

        **Access functions:**

        QTextOption::WrapMode **wordWrapMode** () const
        void
        **setWordWrapMode** (QTextOption::WrapMode **policy** )

        **See also** **QTextOption::WrapMode** .

        **Member Function Documentation**
        """
        ...

    def wordWrapMode(self) -> QtGui.QTextOption.WrapMode:
        """
        https://doc.qt.io/qt-6/qtextedit.html#wordWrapMode-prop

        **wordWrapMode : QTextOption::WrapMode**

        This property holds the mode **QTextEdit**  will use when wrapping text
        by words

        By default, this property is set to
        **QTextOption::WrapAtWordBoundaryOrAnywhere** .

        **Access functions:**

        QTextOption::WrapMode **wordWrapMode** () const
        void
        **setWordWrapMode** (QTextOption::WrapMode **policy** )

        **See also** **QTextOption::WrapMode** .

        **Member Function Documentation**
        """
        ...

    def setLineWrapColumnOrWidth(self, w: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#lineWrapColumnOrWidth-prop

        **lineWrapColumnOrWidth : int**

        This property holds the position (in pixels or columns depending on the
        wrap mode) where text will be wrapped

        If the wrap mode is **FixedPixelWidth** , the value is the number of
        pixels from the left edge of the text edit at which text should be
        wrapped. If the wrap mode is **FixedColumnWidth** , the value is the
        column number (in character columns) from the left edge of the text edit
        at which text should be wrapped.

        By default, this property contains a value of 0.

        **Access functions:**

        int **lineWrapColumnOrWidth** () const
        void
        **setLineWrapColumnOrWidth** (int **w** )

        **See also** **lineWrapMode** .
        """
        ...

    def lineWrapColumnOrWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextedit.html#lineWrapColumnOrWidth-prop

        **lineWrapColumnOrWidth : int**

        This property holds the position (in pixels or columns depending on the
        wrap mode) where text will be wrapped

        If the wrap mode is **FixedPixelWidth** , the value is the number of
        pixels from the left edge of the text edit at which text should be
        wrapped. If the wrap mode is **FixedColumnWidth** , the value is the
        column number (in character columns) from the left edge of the text edit
        at which text should be wrapped.

        By default, this property contains a value of 0.

        **Access functions:**

        int **lineWrapColumnOrWidth** () const
        void
        **setLineWrapColumnOrWidth** (int **w** )

        **See also** **lineWrapMode** .
        """
        ...

    def setLineWrapMode(self, mode: "QTextEdit.LineWrapMode") -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#lineWrapMode-prop

        **lineWrapMode : LineWrapMode**

        This property holds the line wrap mode

        The default mode is **WidgetWidth**  which causes words to be wrapped at
        the right edge of the text edit. Wrapping occurs at whitespace, keeping
        whole words intact. If you want wrapping to occur within words use
        **setWordWrapMode** (). If you set a wrap mode of **FixedPixelWidth**
        or **FixedColumnWidth**  you should also call
        **setLineWrapColumnOrWidth** () with the width you want.

        **Access functions:**

        QTextEdit::LineWrapMode **lineWrapMode** () const
        void
        **setLineWrapMode** (QTextEdit::LineWrapMode **mode** )

        **See also** **lineWrapColumnOrWidth** .
        """
        ...

    def lineWrapMode(self) -> "QTextEdit.LineWrapMode":
        """
        https://doc.qt.io/qt-6/qtextedit.html#lineWrapMode-prop

        **lineWrapMode : LineWrapMode**

        This property holds the line wrap mode

        The default mode is **WidgetWidth**  which causes words to be wrapped at
        the right edge of the text edit. Wrapping occurs at whitespace, keeping
        whole words intact. If you want wrapping to occur within words use
        **setWordWrapMode** (). If you set a wrap mode of **FixedPixelWidth**
        or **FixedColumnWidth**  you should also call
        **setLineWrapColumnOrWidth** () with the width you want.

        **Access functions:**

        QTextEdit::LineWrapMode **lineWrapMode** () const
        void
        **setLineWrapMode** (QTextEdit::LineWrapMode **mode** )

        **See also** **lineWrapColumnOrWidth** .
        """
        ...

    def setUndoRedoEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#undoRedoEnabled-prop

        **undoRedoEnabled : bool**

        This property holds whether undo and redo are enabled.

        Users are only able to undo or redo actions if this property is true,
        and if there is an action that can be undone (or redone).

        **Access functions:**

        bool **isUndoRedoEnabled** () const
        void **setUndoRedoEnabled** (bool
        **enable** )
        """
        ...

    def isUndoRedoEnabled(self) -> bool:
        ...

    def documentTitle(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextedit.html#documentTitle-prop

        **documentTitle : QString**

        This property holds the title of the document parsed from the text.

        By default, for a newly-created, empty document, this property contains
        an empty string.

        **Access functions:**

        QString **documentTitle** () const
        void **setDocumentTitle** (const
        QString & **title** )
        """
        ...

    def setDocumentTitle(self, title: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#documentTitle-prop

        **documentTitle : QString**

        This property holds the title of the document parsed from the text.

        By default, for a newly-created, empty document, this property contains
        an empty string.

        **Access functions:**

        QString **documentTitle** () const
        void **setDocumentTitle** (const
        QString & **title** )
        """
        ...

    def setTabChangesFocus(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#tabChangesFocus-prop

        **tabChangesFocus : bool**

        This property holds whether **Tab** changes focus or is accepted as
        input

        In some occasions text edits should not allow the user to input
        tabulators or change indentation using the **Tab** key, as this breaks
        the focus chain. The default is false.

        **Access functions:**

        bool **tabChangesFocus** () const
        void **setTabChangesFocus** (bool
        **b** )
        """
        ...

    def tabChangesFocus(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#tabChangesFocus-prop

        **tabChangesFocus : bool**

        This property holds whether **Tab** changes focus or is accepted as
        input

        In some occasions text edits should not allow the user to input
        tabulators or change indentation using the **Tab** key, as this breaks
        the focus chain. The default is false.

        **Access functions:**

        bool **tabChangesFocus** () const
        void **setTabChangesFocus** (bool
        **b** )
        """
        ...

    def setAutoFormatting(self, features: "QTextEdit.AutoFormattingFlag") -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#autoFormatting-prop

        **autoFormatting : AutoFormatting**

        This property holds the enabled set of auto formatting features

        The value can be any combination of the values in the
        **AutoFormattingFlag**  enum. The default is **AutoNone** . Choose
        **AutoAll**  to enable all automatic formatting.

        Currently, the only automatic formatting feature provided is
        **AutoBulletList** ; future versions of Qt may offer more.

        **Access functions:**

        QTextEdit::AutoFormatting **autoFormatting** () const
        void
        **setAutoFormatting** (QTextEdit::AutoFormatting **features** )
        """
        ...

    def autoFormatting(self) -> "QTextEdit.AutoFormattingFlag":
        """
        https://doc.qt.io/qt-6/qtextedit.html#autoFormatting-prop

        **autoFormatting : AutoFormatting**

        This property holds the enabled set of auto formatting features

        The value can be any combination of the values in the
        **AutoFormattingFlag**  enum. The default is **AutoNone** . Choose
        **AutoAll**  to enable all automatic formatting.

        Currently, the only automatic formatting feature provided is
        **AutoBulletList** ; future versions of Qt may offer more.

        **Access functions:**

        QTextEdit::AutoFormatting **autoFormatting** () const
        void
        **setAutoFormatting** (QTextEdit::AutoFormatting **features** )
        """
        ...

    def currentCharFormat(self) -> QtGui.QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qtextedit.html#currentCharFormat

        **QTextCharFormat QTextEdit::currentCharFormat() const**

        Returns the char format that is used when inserting new text.

        **See also** **setCurrentCharFormat** ().
        """
        ...

    def setCurrentCharFormat(self, format: QtGui.QTextCharFormat) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setCurrentCharFormat

        **void QTextEdit::setCurrentCharFormat(const QTextCharFormat & format
        )**

        Sets the char format that is be used when inserting new text to
        **format** by calling **QTextCursor::setCharFormat** () on the editor's
        cursor. If the editor has a selection then the char format is directly
        applied to the selection.

        **See also** **currentCharFormat** ().
        """
        ...

    def mergeCurrentCharFormat(self, modifier: QtGui.QTextCharFormat) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#mergeCurrentCharFormat

        **void QTextEdit::mergeCurrentCharFormat(const QTextCharFormat &
        modifier )**

        Merges the properties specified in **modifier** into the current
        character format by calling **QTextCursor::mergeCharFormat**  on the
        editor's cursor. If the editor has a selection then the properties of
        **modifier** are directly applied to the selection.

        **See also** **QTextCursor::mergeCharFormat** ().
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qtextedit.html#alignment

        **Qt::Alignment QTextEdit::alignment() const**

        Returns the alignment of the current paragraph.

        **See also** **setAlignment** ().
        """
        ...

    def currentFont(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qtextedit.html#currentFont

        **QFont QTextEdit::currentFont() const**

        Returns the font of the current format.

        **See also** **setCurrentFont** (), **setFontFamily** (), and
        **setFontPointSize** ().
        """
        ...

    def textColor(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qtextedit.html#textColor

        **QColor QTextEdit::textColor() const**

        Returns the text color of the current format.

        **See also** **setTextColor** ().
        """
        ...

    def fontItalic(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#fontItalic

        **bool QTextEdit::fontItalic() const**

        Returns `true` if the font of the current format is italic; otherwise
        returns false.

        **See also** **setFontItalic** ().
        """
        ...

    def fontUnderline(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextedit.html#fontUnderline

        **bool QTextEdit::fontUnderline() const**

        Returns `true` if the font of the current format is underlined;
        otherwise returns false.

        **See also** **setFontUnderline** ().
        """
        ...

    def fontWeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextedit.html#fontWeight

        **int QTextEdit::fontWeight() const**

        Returns the font weight of the current format.

        **See also** **setFontWeight** (), **setCurrentFont** (),
        **setFontPointSize** (), and **QFont::Weight** .
        """
        ...

    def fontFamily(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextedit.html#fontFamily

        **QString QTextEdit::fontFamily() const**

        Returns the font family of the current format.

        **See also** **setFontFamily** (), **setCurrentFont** (), and
        **setFontPointSize** ().
        """
        ...

    def fontPointSize(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextedit.html#fontPointSize

        **qreal QTextEdit::fontPointSize() const**

        Returns the point size of the font of the current format.

        **See also** **setFontFamily** (), **setCurrentFont** (), and
        **setFontPointSize** ().
        """
        ...

    def setReadOnly(self, ro: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#readOnly-prop

        **readOnly : bool**

        This property holds whether the text edit is read-only

        In a read-only text edit the user can only navigate through the text and
        select text; modifying the text is not possible.

        This property's default is false.

        **Access functions:**

        bool **isReadOnly** () const
        void **setReadOnly** (bool **ro** )
        """
        ...

    def isReadOnly(self) -> bool:
        ...

    def textCursor(self) -> QtGui.QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextedit.html#textCursor

        **QTextCursor QTextEdit::textCursor() const**

        Returns a copy of the **QTextCursor**  that represents the currently
        visible cursor. Note that changes on the returned cursor do not affect
        **QTextEdit** 's cursor; use **setTextCursor** () to update the visible
        cursor.

        **See also** **setTextCursor** ().
        """
        ...

    def setTextCursor(self, cursor: QtGui.QTextCursor) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#setTextCursor

        **void QTextEdit::setTextCursor(const QTextCursor & cursor )**

        Sets the visible **cursor**.

        **See also** **textCursor** ().
        """
        ...

    def document(self) -> QtGui.QTextDocument:
        """
        https://doc.qt.io/qt-6/qtextedit.html#document-prop

        **document : QTextDocument***

        This property holds the underlying document of the text editor.

        **Note:** The editor **does not take ownership of the document** unless
        it is the document's parent object. The parent object of the provided
        document remains the owner of the object. If the previously assigned
        document is a child of the editor then it will be deleted.

        **Access functions:**

        QTextDocument * **document** () const
        void **setDocument**
        (QTextDocument * **document** )
        """
        ...

    def setDocument(self, document: QtGui.QTextDocument) -> None:
        """
        https://doc.qt.io/qt-6/qtextedit.html#document-prop

        **document : QTextDocument***

        This property holds the underlying document of the text editor.

        **Note:** The editor **does not take ownership of the document** unless
        it is the document's parent object. The parent object of the provided
        document remains the owner of the object. If the previously assigned
        document is a child of the editor then it will be deleted.

        **Access functions:**

        QTextDocument * **document** () const
        void **setDocument**
        (QTextDocument * **document** )
        """
        ...

    @property
    def copyAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextedit.html#copyAvailable

        **[signal] void QTextEdit::copyAvailable(bool yes )**

        This signal is emitted when text is selected or de-selected in the text
        edit.

        When text is selected this signal will be emitted with **yes** set to
        true. If no text has been selected or if the selected text is de-
        selected this signal is emitted with **yes** set to false.

        If **yes** is true then **copy** () can be used to copy the selection to
        the clipboard. If **yes** is false then **copy** () does nothing.

        **See also** **selectionChanged** ().
        """
        ...

    @property
    def currentCharFormatChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextedit.html#currentCharFormatChanged

        **[signal] void QTextEdit::currentCharFormatChanged(const
        QTextCharFormat & f )**

        This signal is emitted if the current character format has changed, for
        example caused by a change of the cursor position.

        The new format is **f**.

        **See also** **setCurrentCharFormat** ().
        """
        ...

    @property
    def cursorPositionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextedit.html#cursorPositionChanged

        **[signal] void QTextEdit::cursorPositionChanged()**

        This signal is emitted whenever the position of the cursor changed.
        """
        ...

    @property
    def redoAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextedit.html#redoAvailable

        **[signal] void QTextEdit::redoAvailable(bool available )**

        This signal is emitted whenever redo operations become available (
        **available** is true) or unavailable ( **available** is false).
        """
        ...

    @property
    def selectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextedit.html#selectionChanged

        **[signal] void QTextEdit::selectionChanged()**

        This signal is emitted whenever the selection changes.

        **See also** **copyAvailable** ().
        """
        ...

    @property
    def textChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextedit.html#textChanged

        **[signal] void QTextEdit::textChanged()**

        This signal is emitted whenever the document's content changes; for
        example, when text is inserted or deleted, or when formatting is
        applied.

        **Note:** Notifier signal for property **html** . Notifier signal for
        property **markdown** .
        """
        ...

    @property
    def undoAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextedit.html#undoAvailable

        **[signal] void QTextEdit::undoAvailable(bool available )**

        This signal is emitted whenever undo operations become available (
        **available** is true) or unavailable ( **available** is false).
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QHeaderView(QAbstractItemView):
    """
    https://doc.qt.io/qt-6/qheaderview.html

    **Detailed Description**

    A QHeaderView displays the headers used in item views such as the
    **QTableView**  and **QTreeView**  classes. It takes the place of Qt3's
    `QHeader` class previously used for the same purpose, but uses the Qt's
    model/view architecture for consistency with the item view classes.

    The QHeaderView class is one of the **Model/View Classes**  and is part of
    Qt's **model/view framework** .

    The header gets the data for each section from the model using the
    **QAbstractItemModel::headerData** () function. You can set the data by
    using **QAbstractItemModel::setHeaderData** ().

    Each header has an **orientation** () and a number of sections, given by the
    **count** () function. A section refers to a part of the header - either a
    row or a column, depending on the orientation.

    Sections can be moved and resized using **moveSection** () and
    **resizeSection** (); they can also be hidden and shown with **hideSection**
    () and **showSection** ().

    Each section of a header is described by a section ID, specified by its
    section(), and can be located at a particular **visualIndex** () in the
    header. A section can have a sort indicator set with **setSortIndicator**
    (); this indicates whether the items in the associated item view will be
    sorted in the order given by the section.

    For a horizontal header the section is equivalent to a column in the model,
    and for a vertical header the section is equivalent to a row in the model.

    **Moving Header Sections**

    A header can be fixed in place, or made movable with **setSectionsMovable**
    (). It can be made clickable with **setSectionsClickable** (), and has
    resizing behavior in accordance with **setSectionResizeMode** ().

    **Note:** Double-clicking on a header to resize a section only applies for
    visible rows.

    A header will emit **sectionMoved** () if the user moves a section,
    **sectionResized** () if the user resizes a section, and **sectionClicked**
    () as well as **sectionHandleDoubleClicked** () in response to mouse clicks.
    A header will also emit **sectionCountChanged** ().

    You can identify a section using the **logicalIndex** () and
    **logicalIndexAt** () functions, or by its index position, using the
    **visualIndex** () and **visualIndexAt** () functions. The visual index will
    change if a section is moved, but the logical index will not change.

    **Appearance**

    **QTableWidget**  and **QTableView**  create default headers. If you want
    the headers to be visible, you can use **setVisible** ().

    Not all **ItemDataRole** s will have an effect on a QHeaderView. If you need
    to draw other roles, you can subclass QHeaderView and reimplement
    **paintEvent** (). QHeaderView respects the following item data roles,
    unless they are in conflict with the style (which can happen for styles that
    follow the desktop theme):

    **TextAlignmentRole** , **DisplayRole** , **FontRole** , **DecorationRole**
    , **ForegroundRole** , and **BackgroundRole** .

    **Note:** Each header renders the data for each section itself, and does not
    rely on a delegate. As a result, calling a header's **setItemDelegate** ()
    function will have no effect.

    **See also** **Model/View Programming** , **QListView** , **QTableView** ,
    and **QTreeView** .
    """

    class ResizeMode(enum.Enum):
        Interactive: QHeaderView = ...
        Fixed: QHeaderView = ...
        Stretch: QHeaderView = ...
        ResizeToContents: QHeaderView = ...
        Custom: QHeaderView = ...

    def __init__(
        self, orientation: QtCore.Qt.Orientation, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#QHeaderView

        **QHeaderView::QHeaderView(Qt::Orientation orientation , QWidget *
        parent = nullptr)**

        Creates a new generic header with the given **orientation** and
        **parent**.
        """
        ...

    def isSortIndicatorClearable(self) -> bool:
        ...

    def setSortIndicatorClearable(self, clearable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sortIndicatorClearable-prop

        **[since 6.1] sortIndicatorClearable : bool**

        This property holds whether the sort indicator can be cleared by
        clicking on a section multiple times

        This property controls whether the user is able to remove the sorting
        indicator on a given section by clicking on the section multiple times.
        Normally, clicking on a section will simply change the sorting order for
        that section. By setting this property to true, the sorting indicator
        will be cleared after alternating to ascending and descending; this will
        typically restore the original sorting of a model.

        Setting this property to true has no effect unless **sectionsClickable**
        () is also true (which is the default for certain views, for instance
        **QTableView** , or is automatically set when making a view sortable,
        for instance by calling **QTreeView::setSortingEnabled** ).

        This property was introduced in Qt 6.1.

        **Access functions:**

        bool **isSortIndicatorClearable** () const
        void
        **setSortIndicatorClearable** (bool **clearable** )

        **Notifier signal:**

        void **sortIndicatorClearableChanged** (bool **clearable** )
        """
        ...

    def isFirstSectionMovable(self) -> bool:
        ...

    def setFirstSectionMovable(self, movable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#firstSectionMovable-prop

        **[since 5.11] firstSectionMovable : bool**

        This property holds whether the first column can be moved by the user

        This property controls whether the first column can be moved by the
        user. In a **QTreeView** , the first column holds the tree structure and
        is therefore non-movable by default, even after **setSectionsMovable**
        (true).

        It can be made movable again, for instance in the case of flat lists
        without a tree structure, by calling this method. In such a scenario, it
        is recommended to call **QTreeView::setRootIsDecorated** (false) as
        well.

        Setting it to true has no effect unless **setSectionsMovable** (true) is
        called as well.

        This property was introduced in Qt 5.11.

        **Access functions:**

        bool **isFirstSectionMovable** () const
        void
        **setFirstSectionMovable** (bool **movable** )

        **See also** **setSectionsMovable** ().
        """
        ...

    def resetDefaultSectionSize(self) -> None:
        ...

    def setMaximumSectionSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#maximumSectionSize-prop

        **[since 5.2] maximumSectionSize : int**

        This property holds the maximum size of the header sections.

        The maximum section size is the largest section size allowed. The
        default value for this property is 1048575, which is also the largest
        possible size for a section. Setting maximum to -1 will reset the value
        to the largest section size.

        With exception of stretch this property is honored by all **resize
        modes**

        This property was introduced in Qt 5.2.

        **Access functions:**

        int **maximumSectionSize** () const
        void **setMaximumSectionSize**
        (int **size** )

        **See also** **setSectionResizeMode** () and **defaultSectionSize** .
        """
        ...

    def maximumSectionSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#maximumSectionSize-prop

        **[since 5.2] maximumSectionSize : int**

        This property holds the maximum size of the header sections.

        The maximum section size is the largest section size allowed. The
        default value for this property is 1048575, which is also the largest
        possible size for a section. Setting maximum to -1 will reset the value
        to the largest section size.

        With exception of stretch this property is honored by all **resize
        modes**

        This property was introduced in Qt 5.2.

        **Access functions:**

        int **maximumSectionSize** () const
        void **setMaximumSectionSize**
        (int **size** )

        **See also** **setSectionResizeMode** () and **defaultSectionSize** .
        """
        ...

    def resizeContentsPrecision(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#resizeContentsPrecision

        **[since 5.2] int QHeaderView::resizeContentsPrecision() const**

        Returns how precise **QHeaderView**  will calculate on
        **ResizeToContents** .

        This function was introduced in Qt 5.2.

        **See also** **setResizeContentsPrecision** () and
        **setSectionResizeMode** ().
        """
        ...

    def setResizeContentsPrecision(self, precision: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setResizeContentsPrecision

        **[since 5.2] void QHeaderView::setResizeContentsPrecision(int precision
        )**

        Sets how precise **QHeaderView**  should calculate the size when
        **ResizeToContents**  is used. A low value will provide a less accurate
        but fast auto resize while a higher value will provide a more accurate
        resize that however can be slow.

        The number **precision** specifies how many sections that should be
        consider when calculating the preferred size.

        The default value is 1000 meaning that a horizontal column with auto-
        resize will look at maximum 1000 rows on calculating when doing an auto
        resize.

        Special value 0 means that it will look at only the visible area.
        Special value -1 will imply looking at all elements.

        This value is used in **QTableView::sizeHintForColumn** (),
        **QTableView::sizeHintForRow** () and **QTreeView::sizeHintForColumn**
        (). Reimplementing these functions can make this function not having an
        effect.

        This function was introduced in Qt 5.2.

        **See also** **resizeContentsPrecision** (), **setSectionResizeMode**
        (), **resizeSections** (), **QTableView::sizeHintForColumn** (),
        **QTableView::sizeHintForRow** (), and **QTreeView::sizeHintForColumn**
        ().
        """
        ...

    def setVisible(self, v: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setVisible

        **[override virtual] void QHeaderView::setVisible(bool v )**

        Reimplements an access function for property: **QWidget::visible** .
        """
        ...

    @typing.overload
    def setSectionResizeMode(
        self, logicalIndex: int, mode: "QHeaderView.ResizeMode"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setSectionResizeMode

        **[since 5.0] void
        QHeaderView::setSectionResizeMode(QHeaderView::ResizeMode mode )**

        Sets the constraints on how the header can be resized to those described
        by the given **mode**.

        This function was introduced in Qt 5.0.

        **See also** **sectionResizeMode** (), **length** (), and
        **sectionResized** ().
        """
        ...

    @typing.overload
    def setSectionResizeMode(self, mode: "QHeaderView.ResizeMode") -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setSectionResizeMode-1

        **[since 5.0] void QHeaderView::setSectionResizeMode(int logicalIndex ,
        QHeaderView::ResizeMode mode )**

        Sets the constraints on how the section specified by **logicalIndex** in
        the header can be resized to those described by the given **mode**. The
        logical index should exist at the time this function is called.

        **Note:** This setting will be ignored for the last section if the
        **stretchLastSection**  property is set to true. This is the default for
        the horizontal headers provided by **QTreeView** .

        This function was introduced in Qt 5.0.

        **See also** **setStretchLastSection** () and
        **resizeContentsPrecision** ().
        """
        ...

    def sectionResizeMode(self, logicalIndex: int) -> "QHeaderView.ResizeMode":
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionResizeMode

        **[since 5.0] QHeaderView::ResizeMode QHeaderView::sectionResizeMode(int
        logicalIndex ) const**

        Returns the resize mode that applies to the section specified by the
        given **logicalIndex**.

        This function was introduced in Qt 5.0.

        **See also** **setSectionResizeMode** ().
        """
        ...

    def sectionsClickable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionsClickable

        **[since 5.0] bool QHeaderView::sectionsClickable() const**

        Returns `true` if the header is clickable; otherwise returns `false`. A
        clickable header could be set up to allow the user to change the
        representation of the data in the view related to the header.

        This function was introduced in Qt 5.0.

        **See also** **setSectionsClickable** ().
        """
        ...

    def setSectionsClickable(self, clickable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setSectionsClickable

        **[since 5.0] void QHeaderView::setSectionsClickable(bool clickable )**

        If **clickable** is true, the header will respond to single clicks.

        This function was introduced in Qt 5.0.

        **See also** **sectionsClickable** (), **sectionClicked** (),
        **sectionPressed** (), and **setSortIndicatorShown** ().
        """
        ...

    def sectionsMovable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionsMovable

        **[since 5.0] bool QHeaderView::sectionsMovable() const**

        Returns `true` if the header can be moved by the user; otherwise returns
        false.

        By default, sections are movable in **QTreeView**  (except for the first
        one), and not movable in **QTableView** .

        This function was introduced in Qt 5.0.

        **See also** **setSectionsMovable** ().
        """
        ...

    def setSectionsMovable(self, movable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setSectionsMovable

        **[since 5.0] void QHeaderView::setSectionsMovable(bool movable )**

        If **movable** is true, the header sections may be moved by the user;
        otherwise they are fixed in place.

        When used in combination with **QTreeView** , the first column is not
        movable (since it contains the tree structure), by default. You can make
        it movable with **setFirstSectionMovable** (true).

        This function was introduced in Qt 5.0.

        **See also** **sectionsMovable** (), **sectionMoved** (), and
        **setFirstSectionMovable** ().
        """
        ...

    def initStyleOptionForIndex(
        self, option: "QStyleOptionHeader", logicalIndex: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#initStyleOptionForIndex

        **[virtual protected, since 6.0] void
        QHeaderView::initStyleOptionForIndex(QStyleOptionHeader * option , int
        logicalIndex ) const**

        Initializes the style **option** from the specified **logicalIndex**.
        This function is called by the default implementation of
        **paintSection**  after **initStyleOption**  has been called.

        This function was introduced in Qt 6.0.

        **See also** **paintSection** () and **initStyleOption** ().
        """
        ...

    def initStyleOption(self, option: "QStyleOptionHeader") -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#initStyleOption

        **[virtual protected] void
        QHeaderView::initStyleOption(QStyleOptionHeader * option ) const**

        Initialize **option** with the values from this **QHeaderView** . This
        method is useful for subclasses when they need a **QStyleOptionHeader**
        , but do not want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** () and
        **initStyleOptionForIndex** ().
        """
        ...

    def setOffsetToLastSection(self) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setOffsetToLastSection

        **[slot] void QHeaderView::setOffsetToLastSection()**

        Sets the offset to make the last section visible.

        **See also** **setOffset** (), **sectionPosition** (), and
        **setOffsetToSectionPosition** ().
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#reset

        **[override virtual] void QHeaderView::reset()**

        Reimplements: **QAbstractItemView::reset** ().
        """
        ...

    def restoreState(self, state: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#restoreState

        **bool QHeaderView::restoreState(const QByteArray & state )**

        Restores the **state** of this header view. This function returns `true`
        if the state was restored; otherwise returns false.

        **See also** **saveState** ().
        """
        ...

    def saveState(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qheaderview.html#saveState

        **QByteArray QHeaderView::saveState() const**

        Saves the current state of this header view.

        To restore the saved state, pass the return value to **restoreState**
        ().

        **See also** **restoreState** ().
        """
        ...

    def setMinimumSectionSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#minimumSectionSize-prop

        **minimumSectionSize : int**

        This property holds the minimum size of the header sections.

        The minimum section size is the smallest section size allowed. If the
        minimum section size is set to -1, **QHeaderView**  will use the **font
        metrics**  size.

        This property is honored by all **resize modes** .

        **Access functions:**

        int **minimumSectionSize** () const
        void **setMinimumSectionSize**
        (int **size** )

        **See also** **setSectionResizeMode** () and **defaultSectionSize** .
        """
        ...

    def minimumSectionSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#minimumSectionSize-prop

        **minimumSectionSize : int**

        This property holds the minimum size of the header sections.

        The minimum section size is the smallest section size allowed. If the
        minimum section size is set to -1, **QHeaderView**  will use the **font
        metrics**  size.

        This property is honored by all **resize modes** .

        **Access functions:**

        int **minimumSectionSize** () const
        void **setMinimumSectionSize**
        (int **size** )

        **See also** **setSectionResizeMode** () and **defaultSectionSize** .
        """
        ...

    def setCascadingSectionResizes(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#cascadingSectionResizes-prop

        **cascadingSectionResizes : bool**

        This property holds whether interactive resizing will be cascaded to the
        following sections once the section being resized by the user has
        reached its minimum size

        This property only affects sections that have **Interactive**  as their
        resize mode.

        The default value is false.

        **Access functions:**

        bool **cascadingSectionResizes** () const
        void
        **setCascadingSectionResizes** (bool **enable** )

        **See also** **setSectionResizeMode** ().
        """
        ...

    def cascadingSectionResizes(self) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#cascadingSectionResizes-prop

        **cascadingSectionResizes : bool**

        This property holds whether interactive resizing will be cascaded to the
        following sections once the section being resized by the user has
        reached its minimum size

        This property only affects sections that have **Interactive**  as their
        resize mode.

        The default value is false.

        **Access functions:**

        bool **cascadingSectionResizes** () const
        void
        **setCascadingSectionResizes** (bool **enable** )

        **See also** **setSectionResizeMode** ().
        """
        ...

    def swapSections(self, first: int, second: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#swapSections

        **void QHeaderView::swapSections(int first , int second )**

        Swaps the section at visual index **first** with the section at visual
        index **second**.

        **See also** **moveSection** ().
        """
        ...

    def sectionsHidden(self) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionsHidden

        **bool QHeaderView::sectionsHidden() const**

        Returns `true` if sections in the header has been hidden; otherwise
        returns false;

        **See also** **setSectionHidden** ().
        """
        ...

    def setDefaultAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#defaultAlignment-prop

        **defaultAlignment : Qt::Alignment**

        This property holds the default alignment of the text in each header
        section

        **Access functions:**

        Qt::Alignment **defaultAlignment** () const
        void
        **setDefaultAlignment** (Qt::Alignment **alignment** )
        """
        ...

    def defaultAlignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qheaderview.html#defaultAlignment-prop

        **defaultAlignment : Qt::Alignment**

        This property holds the default alignment of the text in each header
        section

        **Access functions:**

        Qt::Alignment **defaultAlignment** () const
        void
        **setDefaultAlignment** (Qt::Alignment **alignment** )
        """
        ...

    def setDefaultSectionSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#defaultSectionSize-prop

        **defaultSectionSize : int**

        This property holds the default size of the header sections before
        resizing.

        This property only affects sections that have **Interactive**  or
        **Fixed**  as their resize mode.

        By default, the value of this property is style dependent. Thus, when
        the style changes, this property updates from it. Calling
        setDefaultSectionSize() stops the updates, calling
        resetDefaultSectionSize() will restore default behavior.

        **Access functions:**

        int **defaultSectionSize** () const
        void **setDefaultSectionSize**
        (int **size** )
        void **resetDefaultSectionSize** ()

        **See also** **setSectionResizeMode** () and **minimumSectionSize** .
        """
        ...

    def defaultSectionSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#defaultSectionSize-prop

        **defaultSectionSize : int**

        This property holds the default size of the header sections before
        resizing.

        This property only affects sections that have **Interactive**  or
        **Fixed**  as their resize mode.

        By default, the value of this property is style dependent. Thus, when
        the style changes, this property updates from it. Calling
        setDefaultSectionSize() stops the updates, calling
        resetDefaultSectionSize() will restore default behavior.

        **Access functions:**

        int **defaultSectionSize** () const
        void **setDefaultSectionSize**
        (int **size** )
        void **resetDefaultSectionSize** ()

        **See also** **setSectionResizeMode** () and **minimumSectionSize** .
        """
        ...

    def hiddenSectionCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#hiddenSectionCount

        **int QHeaderView::hiddenSectionCount() const**

        Returns the number of sections in the header that has been hidden.

        **See also** **setSectionHidden** () and **isSectionHidden** ().
        """
        ...

    def showSection(self, alogicalIndex: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#showSection

        **void QHeaderView::showSection(int logicalIndex )**

        Shows the section specified by **logicalIndex**.

        **See also** **hideSection** (), **isSectionHidden** (),
        **hiddenSectionCount** (), and **setSectionHidden** ().
        """
        ...

    def hideSection(self, alogicalIndex: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#hideSection

        **void QHeaderView::hideSection(int logicalIndex )**

        Hides the section specified by **logicalIndex**.

        **See also** **showSection** (), **isSectionHidden** (),
        **hiddenSectionCount** (), and **setSectionHidden** ().
        """
        ...

    def visualRegionForSelection(
        self, selection: QtCore.QItemSelection
    ) -> QtGui.QRegion:
        ...

    def setSelection(
        self, rect: QtCore.QRect, flags: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setSelection

        **[override virtual protected] void QHeaderView::setSelection(const
        QRect & rect , QItemSelectionModel::SelectionFlags flags )**

        Reimplements: **QAbstractItemView::setSelection** (const QRect &rect,
        QItemSelectionModel::SelectionFlags flags).

        Selects the items in the given **rect** according to the specified
        **flags**.

        The base class implementation does nothing.
        """
        ...

    def moveCursor(
        self, a0: QAbstractItemView.CursorAction, a1: QtCore.Qt.KeyboardModifier
    ) -> QtCore.QModelIndex:
        ...

    def isIndexHidden(self, index: QtCore.QModelIndex) -> bool:
        ...

    def indexAt(self, p: QtCore.QPoint) -> QtCore.QModelIndex:
        ...

    def scrollTo(
        self, index: QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint
    ) -> None:
        ...

    def visualRect(self, index: QtCore.QModelIndex) -> QtCore.QRect:
        ...

    def rowsInserted(self, parent: QtCore.QModelIndex, start: int, end: int) -> None:
        ...

    def dataChanged(
        self,
        topLeft: QtCore.QModelIndex,
        bottomRight: QtCore.QModelIndex,
        roles: typing.Iterable[int] = ...,
    ) -> None:
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        ...

    def updateGeometries(self) -> None:
        ...

    def verticalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#verticalOffset

        **[override virtual protected] int QHeaderView::verticalOffset() const**

        Reimplements: **QAbstractItemView::verticalOffset() const** .

        Returns the vertical offset of the header. This is 0 for horizontal
        headers.

        **See also** **offset** ().
        """
        ...

    def horizontalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#horizontalOffset

        **[override virtual protected] int QHeaderView::horizontalOffset()
        const**

        Reimplements: **QAbstractItemView::horizontalOffset() const** .

        Returns the horizontal offset of the header. This is 0 for vertical
        headers.

        **See also** **offset** ().
        """
        ...

    def sectionSizeFromContents(self, logicalIndex: int) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionSizeFromContents

        **[virtual protected] QSize QHeaderView::sectionSizeFromContents(int
        logicalIndex ) const**

        Returns the size of the contents of the section specified by the given
        **logicalIndex**.

        **See also** **defaultSectionSize** ().
        """
        ...

    def paintSection(
        self, painter: QtGui.QPainter, rect: QtCore.QRect, logicalIndex: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#paintSection

        **[virtual protected] void QHeaderView::paintSection(QPainter * painter
        , const QRect & rect , int logicalIndex ) const**

        Paints the section specified by the given **logicalIndex** , using the
        given **painter** and **rect**.

        Normally, you do not have to call this function.
        """
        ...

    def mouseDoubleClickEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QHeaderView::mouseDoubleClickEvent(QMouseEvent * e )**

        Reimplements: **QAbstractItemView::mouseDoubleClickEvent** (QMouseEvent
        *event).
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#mouseReleaseEvent

        **[override virtual protected] void
        QHeaderView::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QAbstractItemView::mouseReleaseEvent** (QMouseEvent
        *event).
        """
        ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#mouseMoveEvent

        **[override virtual protected] void
        QHeaderView::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QAbstractItemView::mouseMoveEvent** (QMouseEvent
        *event).
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#mousePressEvent

        **[override virtual protected] void
        QHeaderView::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QAbstractItemView::mousePressEvent** (QMouseEvent
        *event).
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#paintEvent

        **[override virtual protected] void QHeaderView::paintEvent(QPaintEvent
        * e )**

        Reimplements: **QAbstractScrollArea::paintEvent** (QPaintEvent *event).
        """
        ...

    def viewportEvent(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#viewportEvent

        **[override virtual protected] bool QHeaderView::viewportEvent(QEvent *
        e )**

        Reimplements: **QAbstractItemView::viewportEvent** (QEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#event

        **[override virtual protected] bool QHeaderView::event(QEvent * e )**

        Reimplements: **QAbstractItemView::event** (QEvent *event).
        """
        ...

    def currentChanged(
        self, current: QtCore.QModelIndex, old: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#currentChanged

        **[override virtual protected] void QHeaderView::currentChanged(const
        QModelIndex & current , const QModelIndex & old )**

        Reimplements: **QAbstractItemView::currentChanged** (const QModelIndex
        &current, const QModelIndex &previous).
        """
        ...

    @typing.overload
    def initializeSections(self) -> None:
        ...

    @typing.overload
    def initializeSections(self, start: int, end: int) -> None:
        ...

    def initialize(self) -> None:
        ...

    def sectionsAboutToBeRemoved(
        self, parent: QtCore.QModelIndex, logicalFirst: int, logicalLast: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionsAboutToBeRemoved

        **[protected slot] void QHeaderView::sectionsAboutToBeRemoved(const
        QModelIndex & parent , int logicalFirst , int logicalLast )**

        This slot is called when sections are removed from the **parent**.
        **logicalFirst** and **logicalLast** signify where the sections were
        removed.

        If only one section is removed, **logicalFirst** and **logicalLast**
        will be the same.
        """
        ...

    def sectionsInserted(
        self, parent: QtCore.QModelIndex, logicalFirst: int, logicalLast: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionsInserted

        **[protected slot] void QHeaderView::sectionsInserted(const QModelIndex
        & parent , int logicalFirst , int logicalLast )**

        This slot is called when sections are inserted into the **parent**.
        **logicalFirst** and **logicalLast** indices signify where the new
        sections were inserted.

        If only one section is inserted, **logicalFirst** and **logicalLast**
        will be the same.
        """
        ...

    @typing.overload
    def resizeSections(self) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#resizeSections

        **void QHeaderView::resizeSections(QHeaderView::ResizeMode mode )**

        Resizes the sections according to the given **mode** , ignoring the
        current resize mode.

        **See also** **sectionResized** ().
        """
        ...

    @typing.overload
    def resizeSections(self, mode: "QHeaderView.ResizeMode") -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#resizeSections-1

        **[protected slot] void QHeaderView::resizeSections()**

        Resizes the sections according to their size hints. Normally, you do not
        have to call this function.
        """
        ...

    def updateSection(self, logicalIndex: int) -> None:
        ...

    def setOffsetToSectionPosition(self, visualIndex: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setOffsetToSectionPosition

        **[slot] void QHeaderView::setOffsetToSectionPosition(int
        visualSectionNumber )**

        Sets the offset to the start of the section at the given
        **visualSectionNumber**. **visualSectionNumber** is the actual visible
        section when hiddenSections are not considered. That is not always the
        same as **visualIndex** ().

        **See also** **setOffset** () and **sectionPosition** ().
        """
        ...

    def headerDataChanged(
        self, orientation: QtCore.Qt.Orientation, logicalFirst: int, logicalLast: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#headerDataChanged

        **[slot] void QHeaderView::headerDataChanged(Qt::Orientation orientation
        , int logicalFirst , int logicalLast )**

        Updates the changed header sections with the given **orientation** ,
        from **logicalFirst** to **logicalLast** inclusive.
        """
        ...

    def setOffset(self, offset: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setOffset

        **[slot] void QHeaderView::setOffset(int offset )**

        Sets the header's offset to **offset**.

        **See also** **offset** () and **length** ().
        """
        ...

    def sectionsMoved(self) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionsMoved

        **bool QHeaderView::sectionsMoved() const**

        Returns `true` if sections in the header has been moved; otherwise
        returns false;

        **See also** **moveSection** ().
        """
        ...

    def setStretchLastSection(self, stretch: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#stretchLastSection-prop

        **stretchLastSection : bool**

        This property holds whether the last visible section in the header takes
        up all the available space

        The default value is false.

        **Note:** The horizontal headers provided by **QTreeView**  are
        configured with this property set to true, ensuring that the view does
        not waste any of the space assigned to it for its header. If this value
        is set to true, this property will override the resize mode set on the
        last section in the header.

        **Access functions:**

        bool **stretchLastSection** () const
        void **setStretchLastSection**
        (bool **stretch** )

        **See also** **setSectionResizeMode** ().

        **Member Function Documentation**
        """
        ...

    def stretchLastSection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#stretchLastSection-prop

        **stretchLastSection : bool**

        This property holds whether the last visible section in the header takes
        up all the available space

        The default value is false.

        **Note:** The horizontal headers provided by **QTreeView**  are
        configured with this property set to true, ensuring that the view does
        not waste any of the space assigned to it for its header. If this value
        is set to true, this property will override the resize mode set on the
        last section in the header.

        **Access functions:**

        bool **stretchLastSection** () const
        void **setStretchLastSection**
        (bool **stretch** )

        **See also** **setSectionResizeMode** ().

        **Member Function Documentation**
        """
        ...

    def sortIndicatorOrder(self) -> QtCore.Qt.SortOrder:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sortIndicatorOrder

        **Qt::SortOrder QHeaderView::sortIndicatorOrder() const**

        Returns the order for the sort indicator. If no section has a sort
        indicator the return value of this function is undefined.

        **See also** **setSortIndicator** () and **sortIndicatorSection** ().
        """
        ...

    def sortIndicatorSection(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sortIndicatorSection

        **int QHeaderView::sortIndicatorSection() const**

        Returns the logical index of the section that has a sort indicator. By
        default this is section 0.

        **See also** **setSortIndicator** (), **sortIndicatorOrder** (), and
        **setSortIndicatorShown** ().
        """
        ...

    def setSortIndicator(self, logicalIndex: int, order: QtCore.Qt.SortOrder) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setSortIndicator

        **void QHeaderView::setSortIndicator(int logicalIndex , Qt::SortOrder
        order )**

        Sets the sort indicator for the section specified by the given
        **logicalIndex** in the direction specified by **order** , and removes
        the sort indicator from any other section that was showing it.

        **logicalIndex** may be -1, in which case no sort indicator will be
        shown and the model will return to its natural, unsorted order. Note
        that not all models support this and may even crash in this case.

        **See also** **sortIndicatorSection** () and **sortIndicatorOrder** ().
        """
        ...

    def isSortIndicatorShown(self) -> bool:
        ...

    def setSortIndicatorShown(self, show: bool) -> None:
        ...

    def stretchSectionCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#stretchSectionCount

        **int QHeaderView::stretchSectionCount() const**

        Returns the number of sections that are set to resize mode stretch. In
        views, this can be used to see if the headerview needs to resize the
        sections when the view's geometry changes.

        **See also** **stretchLastSection** .
        """
        ...

    def highlightSections(self) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#highlightSections-prop

        **highlightSections : bool**

        This property holds whether the sections containing selected items are
        highlighted

        By default, this property is `false`.

        **Access functions:**

        bool **highlightSections** () const
        void **setHighlightSections**
        (bool **highlight** )
        """
        ...

    def setHighlightSections(self, highlight: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#highlightSections-prop

        **highlightSections : bool**

        This property holds whether the sections containing selected items are
        highlighted

        By default, this property is `false`.

        **Access functions:**

        bool **highlightSections** () const
        void **setHighlightSections**
        (bool **highlight** )
        """
        ...

    def logicalIndex(self, visualIndex: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#logicalIndex

        **int QHeaderView::logicalIndex(int visualIndex ) const**

        Returns the logicalIndex for the section at the given **visualIndex**
        position, or -1 if **visualIndex**  < 0 or **visualIndex**  >=
        **QHeaderView::count** ().

        Note that the **visualIndex**  is not affected by hidden sections.

        **See also** **visualIndex** () and **sectionPosition** ().
        """
        ...

    def visualIndex(self, logicalIndex: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#visualIndex

        **int QHeaderView::visualIndex(int logicalIndex ) const**

        Returns the visual index position of the section specified by the given
        **logicalIndex** , or -1 otherwise.

        Hidden sections still have valid visual indexes.

        **See also** **logicalIndex** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#count

        **int QHeaderView::count() const**

        Returns the number of sections in the header.

        **See also** **sectionCountChanged** () and **length** ().
        """
        ...

    def setSectionHidden(self, logicalIndex: int, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setSectionHidden

        **void QHeaderView::setSectionHidden(int logicalIndex , bool hide )**

        If **hide** is true the section specified by **logicalIndex** is hidden;
        otherwise the section is shown.

        **See also** **isSectionHidden** () and **hiddenSectionCount** ().
        """
        ...

    def isSectionHidden(self, logicalIndex: int) -> bool:
        """
        https://doc.qt.io/qt-6/qheaderview.html#isSectionHidden

        **bool QHeaderView::isSectionHidden(int logicalIndex ) const**

        Returns `true` if the section specified by **logicalIndex** is
        explicitly hidden from the user; otherwise returns `false`.

        **See also** **hideSection** (), **showSection** (),
        **setSectionHidden** (), and **hiddenSectionCount** ().
        """
        ...

    def resizeSection(self, logicalIndex: int, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#resizeSection

        **void QHeaderView::resizeSection(int logicalIndex , int size )**

        Resizes the section specified by **logicalIndex** to **size** measured
        in pixels. The size parameter must be a value larger or equal to zero. A
        size equal to zero is however not recommended. In that situation
        **hideSection**  should be used instead.

        **See also** **sectionResized** (), **sectionSize** (), and
        **hideSection** ().
        """
        ...

    def moveSection(self, from_: int, to: int) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#moveSection

        **void QHeaderView::moveSection(int from , int to )**

        Moves the section at visual index **from** to occupy visual index
        **to**.

        **See also** **sectionsMoved** ().
        """
        ...

    def sectionViewportPosition(self, logicalIndex: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionViewportPosition

        **int QHeaderView::sectionViewportPosition(int logicalIndex ) const**

        Returns the section viewport position of the given **logicalIndex**.

        If the section is hidden, the return value is undefined.

        **See also** **sectionPosition** () and **isSectionHidden** ().
        """
        ...

    def sectionPosition(self, logicalIndex: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionPosition

        **int QHeaderView::sectionPosition(int logicalIndex ) const**

        Returns the section position of the given **logicalIndex** , or -1 if
        the section is hidden. The position is measured in pixels from the first
        visible item's top-left corner to the top-left corner of the item with
        **logicalIndex**. The measurement is along the x-axis for horizontal
        headers and along the y-axis for vertical headers.

        **See also** **sectionViewportPosition** ().
        """
        ...

    def sectionSize(self, logicalIndex: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionSize

        **int QHeaderView::sectionSize(int logicalIndex ) const**

        Returns the width (or height for vertical headers) of the given
        **logicalIndex**.

        **See also** **length** (), **setSectionResizeMode** (), and
        **defaultSectionSize** ().
        """
        ...

    @typing.overload
    def logicalIndexAt(self, position: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#logicalIndexAt

        **int QHeaderView::logicalIndexAt(int position ) const**

        Returns the section that covers the given **position** in the viewport.

        **See also** **visualIndexAt** () and **isSectionHidden** ().
        """
        ...

    @typing.overload
    def logicalIndexAt(self, ax: int, ay: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#logicalIndexAt-1

        **int QHeaderView::logicalIndexAt(int x , int y ) const**

        Returns the logical index of the section at the given coordinate. If the
        header is horizontal **x** will be used, otherwise **y** will be used to
        find the logical index.
        """
        ...

    @typing.overload
    def logicalIndexAt(self, apos: QtCore.QPoint) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#logicalIndexAt-2

        **int QHeaderView::logicalIndexAt(const QPoint & pos ) const**

        Returns the logical index of the section at the position given in
        **pos**. If the header is horizontal the x-coordinate will be used,
        otherwise the y-coordinate will be used to find the logical index.

        **See also** **sectionPosition** ().
        """
        ...

    def visualIndexAt(self, position: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#visualIndexAt

        **int QHeaderView::visualIndexAt(int position ) const**

        Returns the visual index of the section that covers the given
        **position** in the viewport.

        **See also** **logicalIndexAt** ().
        """
        ...

    def sectionSizeHint(self, logicalIndex: int) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionSizeHint

        **int QHeaderView::sectionSizeHint(int logicalIndex ) const**

        Returns a suitable size hint for the section specified by
        **logicalIndex**.

        **Qt::SizeHintRole**

        **See also** **sizeHint** (), **defaultSectionSize** (),
        **minimumSectionSize** (), and **maximumSectionSize** ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sizeHint

        **[override virtual] QSize QHeaderView::sizeHint() const**

        Reimplements: **QAbstractScrollArea::sizeHint() const** .

        Returns a suitable size hint for this header.

        **See also** **sectionSizeHint** ().
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#length

        **int QHeaderView::length() const**

        Returns the length along the orientation of the header.

        **See also** **sizeHint** (), **setSectionResizeMode** (), and
        **offset** ().
        """
        ...

    def offset(self) -> int:
        """
        https://doc.qt.io/qt-6/qheaderview.html#offset

        **int QHeaderView::offset() const**

        Returns the offset of the header: this is the header's left-most (or
        top-most for vertical headers) visible pixel.

        **See also** **setOffset** ().
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qheaderview.html#orientation

        **Qt::Orientation QHeaderView::orientation() const**

        Returns the orientation of the header.

        **See also** **Qt::Orientation** .
        """
        ...

    def setModel(self, model: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qheaderview.html#setModel

        **[override virtual] void QHeaderView::setModel(QAbstractItemModel *
        model )**

        Reimplements: **QAbstractItemView::setModel** (QAbstractItemModel
        *model).
        """
        ...

    @property
    def geometriesChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#geometriesChanged

        **[signal] void QHeaderView::geometriesChanged()**

        This signal is emitted when the header's geometries have changed.
        """
        ...

    @property
    def sectionClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionClicked

        **[signal] void QHeaderView::sectionClicked(int logicalIndex )**

        This signal is emitted when a section is clicked. The section's logical
        index is specified by **logicalIndex**.

        Note that the **sectionPressed**  signal will also be emitted.

        **See also** **setSectionsClickable** () and **sectionPressed** ().
        """
        ...

    @property
    def sectionCountChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionCountChanged

        **[signal] void QHeaderView::sectionCountChanged(int oldCount , int
        newCount )**

        This signal is emitted when the number of sections changes, i.e., when
        sections are added or deleted. The original count is specified by
        **oldCount** , and the new count by **newCount**.

        **See also** **count** (), **length** (), and **headerDataChanged** ().
        """
        ...

    @property
    def sectionDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionDoubleClicked

        **[signal] void QHeaderView::sectionDoubleClicked(int logicalIndex )**

        This signal is emitted when a section is double-clicked. The section's
        logical index is specified by **logicalIndex**.

        **See also** **setSectionsClickable** ().
        """
        ...

    @property
    def sectionEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionEntered

        **[signal] void QHeaderView::sectionEntered(int logicalIndex )**

        This signal is emitted when the cursor moves over the section and the
        left mouse button is pressed. The section's logical index is specified
        by **logicalIndex**.

        **See also** **setSectionsClickable** () and **sectionPressed** ().
        """
        ...

    @property
    def sectionHandleDoubleClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionHandleDoubleClicked

        **[signal] void QHeaderView::sectionHandleDoubleClicked(int logicalIndex
        )**

        This signal is emitted when a section is double-clicked. The section's
        logical index is specified by **logicalIndex**.

        **See also** **setSectionsClickable** ().
        """
        ...

    @property
    def sectionMoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionMoved

        **[signal] void QHeaderView::sectionMoved(int logicalIndex , int
        oldVisualIndex , int newVisualIndex )**

        This signal is emitted when a section is moved. The section's logical
        index is specified by **logicalIndex** , the old index by
        **oldVisualIndex** , and the new index position by **newVisualIndex**.

        **See also** **moveSection** ().
        """
        ...

    @property
    def sectionPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionPressed

        **[signal] void QHeaderView::sectionPressed(int logicalIndex )**

        This signal is emitted when a section is pressed. The section's logical
        index is specified by **logicalIndex**.

        **See also** **setSectionsClickable** ().
        """
        ...

    @property
    def sectionResized(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sectionResized

        **[signal] void QHeaderView::sectionResized(int logicalIndex , int
        oldSize , int newSize )**

        This signal is emitted when a section is resized. The section's logical
        number is specified by **logicalIndex** , the old size by **oldSize** ,
        and the new size by **newSize**.

        **See also** **resizeSection** ().
        """
        ...

    @property
    def sortIndicatorChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qheaderview.html#sortIndicatorChanged

        **[signal] void QHeaderView::sortIndicatorChanged(int logicalIndex ,
        Qt::SortOrder order )**

        This signal is emitted when the section containing the sort indicator or
        the order indicated is changed. The section's logical index is specified
        by **logicalIndex** and the sort order is specified by **order**.

        **See also** **setSortIndicator** ().
        """
        ...

    @property
    def sortIndicatorClearableChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QStringDecoder(QStringConverter):
    """
    https://doc.qt.io/qt-6/qstringdecoder.html

    **Detailed Description**

    A text decoder converts text an encoded text format that uses a specific
    encoding into Qt's internal representation.

    Converting encoded data into a **QString**  can be achieved using the
    following code:

    **QByteArray**  encodedString = "...";
        auto toUtf16 =
    QStringDecoder(QStringDecoder::Utf8);
        **QString**  string =
    toUtf16(encodedString);

    The decoder remembers any state that is required between calls, so
    converting data received in chunks, for example, when receiving it over a
    network, is just as easy, by calling the decoder whenever new data is
    available:

    auto toUtf16 = QStringDecoder(QStringDecoder::Utf8);

        **QString**
    string;
        while (new_data_available()) {
            **QByteArray**  chunk =
    get_new_data();
            string += toUtf16(chunk);
        }

    The QStringDecoder object maintains state between chunks and therefore works
    correctly even if chunks are split in the middle of a multi-byte character
    sequence.

    QStringDecoder objects can't be copied because of their internal state, but
    can be moved.

    **See also** **QStringConverter**  and **QStringEncoder** .
    """

    @typing.overload
    def __init__(
        self,
        encoding: QStringConverter.Encoding,
        flags: QStringConverterBase.Flag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstringdecoder.html#QStringDecoder-1

        **QStringDecoder::QStringDecoder(QStringConverter::Encoding encoding ,
        QStringConverter::Flags flags = Flag::Default)**

        Creates an decoder object using **encoding** and **flags**.
        """
        ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstringdecoder.html#QStringDecoder-2

        **QStringDecoder::QStringDecoder()**

        Default constructs an decoder. The default decoder is not valid, and
        can't be used for converting text.
        """
        ...

    @typing.overload
    def __init__(self, name: str, flags: QStringConverterBase.Flag = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstringdecoder.html#QStringDecoder-3

        **QStringDecoder::QStringDecoder(const char * name ,
        QStringConverter::Flags flags = Flag::Default)**

        Creates an decoder object using **name** and **flags**. If **name** is
        not the name of a known encoding an invalid converter will get created.

        **See also** **isValid** ().
        """
        ...

    def decode(self, ba: typing.Union[QByteArray, bytes, bytearray, memoryview]) -> str:
        ...

    def __call__(
        self, ba: typing.Union[QByteArray, bytes, bytearray, memoryview]
    ) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6.QtWidgets import *


class QDoubleSpinBox(QAbstractSpinBox):
    """
    https://doc.qt.io/qt-6/qdoublespinbox.html

    **Detailed Description**

    QDoubleSpinBox allows the user to choose a value by clicking the up and down
    buttons or by pressing Up or Down on the keyboard to increase or decrease
    the value currently displayed. The user can also type the value in manually.
    The spin box supports double values but can be extended to use different
    strings with **validate** (), **textFromValue** () and **valueFromText** ().

    Every time the value changes QDoubleSpinBox emits **valueChanged** () and
    **textChanged** () signals, the former providing a double and the latter a
    **QString** . The **textChanged** () signal provides the value with both
    **prefix** () and **suffix** (). The current value can be fetched with
    **value** () and set with **setValue** ().

    Note: QDoubleSpinBox will round numbers so they can be displayed with the
    current precision. In a QDoubleSpinBox with decimals set to 2, calling
    **setValue** (2.555) will cause **value** () to return 2.56.

    Clicking the up and down buttons or using the keyboard accelerator's Up and
    Down arrows will increase or decrease the current value in steps of size
    **singleStep** (). If you want to change this behavior you can reimplement
    the virtual function **stepBy** (). The minimum and maximum value and the
    step size can be set using one of the constructors, and can be changed later
    with **setMinimum** (), **setMaximum** () and **setSingleStep** (). The
    spinbox has a default precision of 2 decimal places but this can be changed
    using **setDecimals** ().

    Most spin boxes are directional, but QDoubleSpinBox can also operate as a
    circular spin box, i.e. if the range is 0.0-99.9 and the current value is
    99.9, clicking "up" will give 0 if **wrapping** () is set to true. Use
    **setWrapping** () if you want circular behavior.

    The displayed value can be prepended and appended with arbitrary strings
    indicating, for example, currency or the unit of measurement. See
    **setPrefix** () and **setSuffix** (). The text in the spin box is retrieved
    with **text** () (which includes any **prefix** () and **suffix** ()), or
    with **cleanText** () (which has no **prefix** (), no **suffix** () and no
    leading or trailing whitespace).

    It is often desirable to give the user a special (often default) choice in
    addition to the range of numeric values. See **setSpecialValueText** () for
    how to do this with QDoubleSpinBox.

    **Note:** The displayed value of the QDoubleSpinBox is limited to 18
    characters in addition to eventual prefix and suffix content. This
    limitation is used to keep the double spin box usable even with extremely
    large values.

    **See also** **QSpinBox** , **QDateTimeEdit** , **QSlider** , and **Spin
    Boxes Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#QDoubleSpinBox

        **QDoubleSpinBox::QDoubleSpinBox(QWidget * parent = nullptr)**

        Constructs a spin box with 0.0 as minimum value and 99.99 as maximum
        value, a step value of 1.0 and a precision of 2 decimal places. The
        value is initially set to 0.00. The spin box has the given **parent**.

        **See also** **setMinimum** (), **setMaximum** (), and **setSingleStep**
        ().
        """
        ...

    def setStepType(self, stepType: QAbstractSpinBox.StepType) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#setStepType

        **[since 5.12] void
        QDoubleSpinBox::setStepType(QAbstractSpinBox::StepType stepType )**

        Sets the step type for the spin box to **stepType** , which is single
        step or adaptive decimal step.

        Adaptive decimal step means that the step size will continuously be
        adjusted to one power of ten below the current **value** . So when the
        value is 1100, the step is set to 100, so stepping up once increases it
        to 1200. For 1200 stepping up takes it to 1300. For negative values,
        stepping down from -1100 goes to -1200.

        It also works for any decimal values, 0.041 is increased to 0.042 by
        stepping once.

        Step direction is taken into account to handle edges cases, so that
        stepping down from 100 takes the value to 99 instead of 90. Thus a step
        up followed by a step down -- or vice versa -- always lands on the
        starting value; 99 -> 100 -> 99.

        Setting this will cause the spin box to disregard the value of
        **singleStep** , although it is preserved so that **singleStep**  comes
        into effect if adaptive decimal step is later turned off.

        **Note:** Setter function for property **stepType** .

        This function was introduced in Qt 5.12.

        **See also** **stepType** ().
        """
        ...

    def stepType(self) -> QAbstractSpinBox.StepType:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#stepType-prop

        **stepType : StepType**

        This property holds the step type.

        The step type can be single step or adaptive decimal step.

        **Access functions:**

        QAbstractSpinBox::StepType **stepType** () const
        void
        ****setStepType** ** (QAbstractSpinBox::StepType **stepType** )
        """
        ...

    def setValue(self, val: float) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#value-prop

        **value : double**

        This property holds the value of the spin box

        setValue() will emit **valueChanged** () if the new value is different
        from the old one. The value property has a second notifier signal which
        includes the spin box's prefix and suffix.

        Note: The value will be rounded so it can be displayed with the current
        setting of decimals.

        **Access functions:**

        double **value** () const
        void **setValue** (double **val** )

        **Notifier signal:**

        void ****valueChanged** ** (double **d** )

        **See also** **decimals** .

        **Member Function Documentation**
        """
        ...

    def fixup(self, str: str) -> str:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#fixup

        **[override virtual] void QDoubleSpinBox::fixup(QString & input )
        const**

        Reimplements: **QAbstractSpinBox::fixup(QString &input) const** .
        """
        ...

    def textFromValue(self, v: float) -> str:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#textFromValue

        **[virtual] QString QDoubleSpinBox::textFromValue(double value ) const**

        This virtual function is used by the spin box whenever it needs to
        display the given **value**. The default implementation returns a string
        containing **value** printed using **QWidget::locale** ().toString(
        **value** , **QLatin1Char** ('f'), **decimals** ()) and will remove the
        thousand separator unless **setGroupSeparatorShown** () is set.
        Reimplementations may return anything.

        Note: **QDoubleSpinBox**  does not call this function for
        **specialValueText** () and that neither **prefix** () nor **suffix** ()
        should be included in the return value.

        If you reimplement this, you may also need to reimplement
        **valueFromText** ().

        **See also** **valueFromText** () and **QLocale::groupSeparator** ().
        """
        ...

    def valueFromText(self, text: str) -> float:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#valueFromText

        **[virtual] double QDoubleSpinBox::valueFromText(const QString & text )
        const**

        This virtual function is used by the spin box whenever it needs to
        interpret **text** entered by the user as a value.

        Subclasses that need to display spin box values in a non-numeric way
        need to reimplement this function.

        Note: **QDoubleSpinBox**  handles **specialValueText** () separately;
        this function is only concerned with the other values.

        **See also** **textFromValue** () and **validate** ().
        """
        ...

    def validate(
        self, input: str, pos: int
    ) -> typing.Tuple[QtGui.QValidator.State, str, int]:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#validate

        **[override virtual] QValidator::State QDoubleSpinBox::validate(QString
        & text , int & pos ) const**

        Reimplements: **QAbstractSpinBox::validate(QString &input, int &pos)
        const** .
        """
        ...

    def setDecimals(self, prec: int) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#decimals-prop

        **decimals : int**

        This property holds the precision of the spin box, in decimals

        Sets how many decimals the spinbox will use for displaying and
        interpreting doubles.

        **Warning:** The maximum value for **decimals** is DBL_MAX_10_EXP +
        DBL_DIG (ie. 323) because of the limitations of the double type.

        Note: The maximum, minimum and value might change as a result of
        changing this property.

        **Access functions:**

        int **decimals** () const
        void **setDecimals** (int **prec** )
        """
        ...

    def decimals(self) -> int:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#decimals-prop

        **decimals : int**

        This property holds the precision of the spin box, in decimals

        Sets how many decimals the spinbox will use for displaying and
        interpreting doubles.

        **Warning:** The maximum value for **decimals** is DBL_MAX_10_EXP +
        DBL_DIG (ie. 323) because of the limitations of the double type.

        Note: The maximum, minimum and value might change as a result of
        changing this property.

        **Access functions:**

        int **decimals** () const
        void **setDecimals** (int **prec** )
        """
        ...

    def setRange(self, min: float, max: float) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#setRange

        **void QDoubleSpinBox::setRange(double minimum , double maximum )**

        Convenience function to set the **minimum** and **maximum** values with
        a single function call.

        Note: The maximum and minimum values will be rounded to match the
        decimals property.

        setRange(minimum, maximum);

        is equivalent to:

        setMinimum(minimum);
            setMaximum(maximum);

        **See also** **minimum**  and **maximum** .
        """
        ...

    def setMaximum(self, max: float) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#maximum-prop

        **maximum : double**

        This property holds the maximum value of the spin box

        When setting this property the **minimum**  is adjusted if necessary, to
        ensure that the range remains valid.

        The default maximum value is 99.99.

        Note: The maximum value will be rounded to match the decimals property.

        **Access functions:**

        double **maximum** () const
        void **setMaximum** (double **max** )

        **See also** **decimals**  and **setRange** ().
        """
        ...

    def maximum(self) -> float:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#maximum-prop

        **maximum : double**

        This property holds the maximum value of the spin box

        When setting this property the **minimum**  is adjusted if necessary, to
        ensure that the range remains valid.

        The default maximum value is 99.99.

        Note: The maximum value will be rounded to match the decimals property.

        **Access functions:**

        double **maximum** () const
        void **setMaximum** (double **max** )

        **See also** **decimals**  and **setRange** ().
        """
        ...

    def setMinimum(self, min: float) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#minimum-prop

        **minimum : double**

        This property holds the minimum value of the spin box

        When setting this property the **maximum**  is adjusted if necessary to
        ensure that the range remains valid.

        The default minimum value is 0.0.

        Note: The minimum value will be rounded to match the decimals property.

        **Access functions:**

        double **minimum** () const
        void **setMinimum** (double **min** )

        **See also** **decimals** , **setRange** (), and **specialValueText** .
        """
        ...

    def minimum(self) -> float:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#minimum-prop

        **minimum : double**

        This property holds the minimum value of the spin box

        When setting this property the **maximum**  is adjusted if necessary to
        ensure that the range remains valid.

        The default minimum value is 0.0.

        Note: The minimum value will be rounded to match the decimals property.

        **Access functions:**

        double **minimum** () const
        void **setMinimum** (double **min** )

        **See also** **decimals** , **setRange** (), and **specialValueText** .
        """
        ...

    def setSingleStep(self, val: float) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#singleStep-prop

        **singleStep : double**

        This property holds the step value

        When the user uses the arrows to change the spin box's value the value
        will be incremented/decremented by the amount of the singleStep. The
        default value is 1.0. Setting a singleStep value of less than 0 does
        nothing.

        **Access functions:**

        double **singleStep** () const
        void **setSingleStep** (double **val**
        )
        """
        ...

    def singleStep(self) -> float:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#singleStep-prop

        **singleStep : double**

        This property holds the step value

        When the user uses the arrows to change the spin box's value the value
        will be incremented/decremented by the amount of the singleStep. The
        default value is 1.0. Setting a singleStep value of less than 0 does
        nothing.

        **Access functions:**

        double **singleStep** () const
        void **setSingleStep** (double **val**
        )
        """
        ...

    def cleanText(self) -> str:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#cleanText-prop

        **[read-only] cleanText : const QString**

        This property holds the text of the spin box excluding any prefix,
        suffix, or leading or trailing whitespace.

        **Access functions:**

        QString **cleanText** () const

        **See also** **text** , **QDoubleSpinBox::prefix** , and
        **QDoubleSpinBox::suffix** .
        """
        ...

    def setSuffix(self, s: str) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#suffix-prop

        **suffix : QString**

        This property holds the suffix of the spin box

        The suffix is appended to the end of the displayed value. Typical use is
        to display a unit of measurement or a currency symbol. For example:

        spinbox->setSuffix(" km");

        To turn off the suffix display, set this property to an empty string.
        The default is no suffix. The suffix is not displayed for the
        **minimum** () if **specialValueText** () is set.

        If no suffix is set, suffix() returns an empty string.

        **Access functions:**

        QString **suffix** () const
        void **setSuffix** (const QString &
        **suffix** )

        **See also** **prefix** (), **setPrefix** (), **specialValueText** (),
        and **setSpecialValueText** ().
        """
        ...

    def suffix(self) -> str:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#suffix-prop

        **suffix : QString**

        This property holds the suffix of the spin box

        The suffix is appended to the end of the displayed value. Typical use is
        to display a unit of measurement or a currency symbol. For example:

        spinbox->setSuffix(" km");

        To turn off the suffix display, set this property to an empty string.
        The default is no suffix. The suffix is not displayed for the
        **minimum** () if **specialValueText** () is set.

        If no suffix is set, suffix() returns an empty string.

        **Access functions:**

        QString **suffix** () const
        void **setSuffix** (const QString &
        **suffix** )

        **See also** **prefix** (), **setPrefix** (), **specialValueText** (),
        and **setSpecialValueText** ().
        """
        ...

    def setPrefix(self, p: str) -> None:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#prefix-prop

        **prefix : QString**

        This property holds the spin box's prefix

        The prefix is prepended to the start of the displayed value. Typical use
        is to display a unit of measurement or a currency symbol. For example:

        spinbox->setPrefix("$");

        To turn off the prefix display, set this property to an empty string.
        The default is no prefix. The prefix is not displayed when **value** ()
        == **minimum** () and **specialValueText** () is set.

        If no prefix is set, prefix() returns an empty string.

        **Access functions:**

        QString **prefix** () const
        void **setPrefix** (const QString &
        **prefix** )

        **See also** **suffix** (), **setSuffix** (), **specialValueText** (),
        and **setSpecialValueText** ().
        """
        ...

    def prefix(self) -> str:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#prefix-prop

        **prefix : QString**

        This property holds the spin box's prefix

        The prefix is prepended to the start of the displayed value. Typical use
        is to display a unit of measurement or a currency symbol. For example:

        spinbox->setPrefix("$");

        To turn off the prefix display, set this property to an empty string.
        The default is no prefix. The prefix is not displayed when **value** ()
        == **minimum** () and **specialValueText** () is set.

        If no prefix is set, prefix() returns an empty string.

        **Access functions:**

        QString **prefix** () const
        void **setPrefix** (const QString &
        **prefix** )

        **See also** **suffix** (), **setSuffix** (), **specialValueText** (),
        and **setSpecialValueText** ().
        """
        ...

    def value(self) -> float:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#value-prop

        **value : double**

        This property holds the value of the spin box

        setValue() will emit **valueChanged** () if the new value is different
        from the old one. The value property has a second notifier signal which
        includes the spin box's prefix and suffix.

        Note: The value will be rounded so it can be displayed with the current
        setting of decimals.

        **Access functions:**

        double **value** () const
        void **setValue** (double **val** )

        **Notifier signal:**

        void ****valueChanged** ** (double **d** )

        **See also** **decimals** .

        **Member Function Documentation**
        """
        ...

    @property
    def textChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#textChanged

        **[signal, since 5.14] void QDoubleSpinBox::textChanged(const QString &
        text )**

        This signal is emitted whenever the spin box's text is changed. The new
        text is passed in **text** with **prefix** () and **suffix** ().

        This function was introduced in Qt 5.14.
        """
        ...

    @property
    def valueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdoublespinbox.html#valueChanged

        **[signal] void QDoubleSpinBox::valueChanged(double d )**

        This signal is emitted whenever the spin box's value is changed. The new
        value is passed in **d**.

        **Note:** Notifier signal for property **value** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtCore import *


class QTimerEvent(QEvent):
    """
    https://doc.qt.io/qt-6/qtimerevent.html

    **Detailed Description**

    Timer events are sent at regular intervals to objects that have started one
    or more timers. Each timer has a unique identifier. A timer is started with
    **QObject::startTimer** ().

    The **QTimer**  class provides a high-level programming interface that uses
    signals instead of events. It also provides single-shot timers.

    The event handler **QObject::timerEvent** () receives timer events.

    **See also** **QTimer** , **QObject::timerEvent** (),
    **QObject::startTimer** (), and **QObject::killTimer** ().
    """

    def __init__(self, timerId: int) -> None:
        """
        https://doc.qt.io/qt-6/qtimerevent.html#QTimerEvent-2

        **QTimerEvent::QTimerEvent(int timerId )**

        Constructs a timer event object with the timer identifier set to
        **timerId**.
        """
        ...

    def clone(self) -> "QTimerEvent":
        ...

    def timerId(self) -> int:
        """
        https://doc.qt.io/qt-6/qtimerevent.html#timerId

        **int QTimerEvent::timerId() const**

        Returns the unique timer identifier, which is the same identifier as
        returned from **QObject::startTimer** ().
        """
        ...
